#line 2 "src/xkbcomp/scanner.c"

#line 4 "src/xkbcomp/scanner.c"

#define  YY_INT_ALIGNED short int

/* A lexical scanner generated by flex */

#define FLEX_SCANNER
#define YY_FLEX_MAJOR_VERSION 2
#define YY_FLEX_MINOR_VERSION 5
#define YY_FLEX_SUBMINOR_VERSION 35
#if YY_FLEX_SUBMINOR_VERSION > 0
#define FLEX_BETA
#endif

/* First, we deal with  platform-specific or compiler-specific issues. */

/* begin standard C headers. */
#include <stdio.h>
#include <string.h>
#include <errno.h>
#include <stdlib.h>

/* end standard C headers. */

/* flex integer type definitions */

#ifndef FLEXINT_H
#define FLEXINT_H

/* C99 systems have <inttypes.h>. Non-C99 systems may or may not. */

#if defined (__STDC_VERSION__) && __STDC_VERSION__ >= 199901L

/* C99 says to define __STDC_LIMIT_MACROS before including stdint.h,
 * if you want the limit (max/min) macros for int types. 
 */
#ifndef __STDC_LIMIT_MACROS
#define __STDC_LIMIT_MACROS 1
#endif

#include <inttypes.h>
typedef int8_t flex_int8_t;
typedef uint8_t flex_uint8_t;
typedef int16_t flex_int16_t;
typedef uint16_t flex_uint16_t;
typedef int32_t flex_int32_t;
typedef uint32_t flex_uint32_t;
#else
typedef signed char flex_int8_t;
typedef short int flex_int16_t;
typedef int flex_int32_t;
typedef unsigned char flex_uint8_t; 
typedef unsigned short int flex_uint16_t;
typedef unsigned int flex_uint32_t;

/* Limits of integral types. */
#ifndef INT8_MIN
#define INT8_MIN               (-128)
#endif
#ifndef INT16_MIN
#define INT16_MIN              (-32767-1)
#endif
#ifndef INT32_MIN
#define INT32_MIN              (-2147483647-1)
#endif
#ifndef INT8_MAX
#define INT8_MAX               (127)
#endif
#ifndef INT16_MAX
#define INT16_MAX              (32767)
#endif
#ifndef INT32_MAX
#define INT32_MAX              (2147483647)
#endif
#ifndef UINT8_MAX
#define UINT8_MAX              (255U)
#endif
#ifndef UINT16_MAX
#define UINT16_MAX             (65535U)
#endif
#ifndef UINT32_MAX
#define UINT32_MAX             (4294967295U)
#endif

#endif /* ! C99 */

#endif /* ! FLEXINT_H */

#ifdef __cplusplus

/* The "const" storage-class-modifier is valid. */
#define YY_USE_CONST

#else	/* ! __cplusplus */

/* C99 requires __STDC__ to be defined as 1. */
#if defined (__STDC__)

#define YY_USE_CONST

#endif	/* defined (__STDC__) */
#endif	/* ! __cplusplus */

#ifdef YY_USE_CONST
#define yyconst const
#else
#define yyconst
#endif

/* Returned upon end-of-file. */
#define YY_NULL 0

/* Promotes a possibly negative, possibly signed char to an unsigned
 * integer for use as an array index.  If the signed char is negative,
 * we want to instead treat it as an 8-bit unsigned char, hence the
 * double cast.
 */
#define YY_SC_TO_UI(c) ((unsigned int) (unsigned char) c)

/* An opaque pointer. */
#ifndef YY_TYPEDEF_YY_SCANNER_T
#define YY_TYPEDEF_YY_SCANNER_T
typedef void* yyscan_t;
#endif

/* For convenience, these vars (plus the bison vars far below)
   are macros in the reentrant scanner. */
#define yyin yyg->yyin_r
#define yyout yyg->yyout_r
#define yyextra yyg->yyextra_r
#define yyleng yyg->yyleng_r
#define yytext yyg->yytext_r
#define yylineno (YY_CURRENT_BUFFER_LVALUE->yy_bs_lineno)
#define yycolumn (YY_CURRENT_BUFFER_LVALUE->yy_bs_column)
#define yy_flex_debug yyg->yy_flex_debug_r

/* Enter a start condition.  This macro really ought to take a parameter,
 * but we do it the disgusting crufty way forced on us by the ()-less
 * definition of BEGIN.
 */
#define BEGIN yyg->yy_start = 1 + 2 *

/* Translate the current start state into a value that can be later handed
 * to BEGIN to return to the state.  The YYSTATE alias is for lex
 * compatibility.
 */
#define YY_START ((yyg->yy_start - 1) / 2)
#define YYSTATE YY_START

/* Action number for EOF rule of a given start state. */
#define YY_STATE_EOF(state) (YY_END_OF_BUFFER + state + 1)

/* Special action meaning "start processing a new file". */
#define YY_NEW_FILE _xkbcommon_restart(yyin ,yyscanner )

#define YY_END_OF_BUFFER_CHAR 0

/* Size of default input buffer. */
#ifndef YY_BUF_SIZE
#ifdef __ia64__
/* On IA-64, the buffer size is 16k, not 8k.
 * Moreover, YY_BUF_SIZE is 2*YY_READ_BUF_SIZE in the general case.
 * Ditto for the __ia64__ case accordingly.
 */
#define YY_BUF_SIZE 32768
#else
#define YY_BUF_SIZE 16384
#endif /* __ia64__ */
#endif

/* The state buf must be large enough to hold one state per character in the main buffer.
 */
#define YY_STATE_BUF_SIZE   ((YY_BUF_SIZE + 2) * sizeof(yy_state_type))

#ifndef YY_TYPEDEF_YY_BUFFER_STATE
#define YY_TYPEDEF_YY_BUFFER_STATE
typedef struct yy_buffer_state *YY_BUFFER_STATE;
#endif

#define EOB_ACT_CONTINUE_SCAN 0
#define EOB_ACT_END_OF_FILE 1
#define EOB_ACT_LAST_MATCH 2

    /* Note: We specifically omit the test for yy_rule_can_match_eol because it requires
     *       access to the local variable yy_act. Since yyless() is a macro, it would break
     *       existing scanners that call yyless() from OUTSIDE _xkbcommon_lex. 
     *       One obvious solution it to make yy_act a global. I tried that, and saw
     *       a 5% performance hit in a non-yylineno scanner, because yy_act is
     *       normally declared as a register variable-- so it is not worth it.
     */
    #define  YY_LESS_LINENO(n) \
            do { \
                int yyl;\
                for ( yyl = n; yyl < yyleng; ++yyl )\
                    if ( yytext[yyl] == '\n' )\
                        --yylineno;\
            }while(0)
    
/* Return all but the first "n" matched characters back to the input stream. */
#define yyless(n) \
	do \
		{ \
		/* Undo effects of setting up yytext. */ \
        int yyless_macro_arg = (n); \
        YY_LESS_LINENO(yyless_macro_arg);\
		*yy_cp = yyg->yy_hold_char; \
		YY_RESTORE_YY_MORE_OFFSET \
		yyg->yy_c_buf_p = yy_cp = yy_bp + yyless_macro_arg - YY_MORE_ADJ; \
		YY_DO_BEFORE_ACTION; /* set up yytext again */ \
		} \
	while ( 0 )

#define unput(c) yyunput( c, yyg->yytext_ptr , yyscanner )

#ifndef YY_TYPEDEF_YY_SIZE_T
#define YY_TYPEDEF_YY_SIZE_T
typedef size_t yy_size_t;
#endif

#ifndef YY_STRUCT_YY_BUFFER_STATE
#define YY_STRUCT_YY_BUFFER_STATE
struct yy_buffer_state
	{
	FILE *yy_input_file;

	char *yy_ch_buf;		/* input buffer */
	char *yy_buf_pos;		/* current position in input buffer */

	/* Size of input buffer in bytes, not including room for EOB
	 * characters.
	 */
	yy_size_t yy_buf_size;

	/* Number of characters read into yy_ch_buf, not including EOB
	 * characters.
	 */
	int yy_n_chars;

	/* Whether we "own" the buffer - i.e., we know we created it,
	 * and can realloc() it to grow it, and should free() it to
	 * delete it.
	 */
	int yy_is_our_buffer;

	/* Whether this is an "interactive" input source; if so, and
	 * if we're using stdio for input, then we want to use getc()
	 * instead of fread(), to make sure we stop fetching input after
	 * each newline.
	 */
	int yy_is_interactive;

	/* Whether we're considered to be at the beginning of a line.
	 * If so, '^' rules will be active on the next match, otherwise
	 * not.
	 */
	int yy_at_bol;

    int yy_bs_lineno; /**< The line count. */
    int yy_bs_column; /**< The column count. */
    
	/* Whether to try to fill the input buffer when we reach the
	 * end of it.
	 */
	int yy_fill_buffer;

	int yy_buffer_status;

#define YY_BUFFER_NEW 0
#define YY_BUFFER_NORMAL 1
	/* When an EOF's been seen but there's still some text to process
	 * then we mark the buffer as YY_EOF_PENDING, to indicate that we
	 * shouldn't try reading from the input source any more.  We might
	 * still have a bunch of tokens to match, though, because of
	 * possible backing-up.
	 *
	 * When we actually see the EOF, we change the status to "new"
	 * (via _xkbcommon_restart()), so that the user can continue scanning by
	 * just pointing yyin at a new input file.
	 */
#define YY_BUFFER_EOF_PENDING 2

	};
#endif /* !YY_STRUCT_YY_BUFFER_STATE */

/* We provide macros for accessing buffer states in case in the
 * future we want to put the buffer states in a more general
 * "scanner state".
 *
 * Returns the top of the stack, or NULL.
 */
#define YY_CURRENT_BUFFER ( yyg->yy_buffer_stack \
                          ? yyg->yy_buffer_stack[yyg->yy_buffer_stack_top] \
                          : NULL)

/* Same as previous macro, but useful when we know that the buffer stack is not
 * NULL or when we need an lvalue. For internal use only.
 */
#define YY_CURRENT_BUFFER_LVALUE yyg->yy_buffer_stack[yyg->yy_buffer_stack_top]

void _xkbcommon_restart (FILE *input_file ,yyscan_t yyscanner );
void _xkbcommon__switch_to_buffer (YY_BUFFER_STATE new_buffer ,yyscan_t yyscanner );
YY_BUFFER_STATE _xkbcommon__create_buffer (FILE *file,int size ,yyscan_t yyscanner );
void _xkbcommon__delete_buffer (YY_BUFFER_STATE b ,yyscan_t yyscanner );
void _xkbcommon__flush_buffer (YY_BUFFER_STATE b ,yyscan_t yyscanner );
void _xkbcommon_push_buffer_state (YY_BUFFER_STATE new_buffer ,yyscan_t yyscanner );
void _xkbcommon_pop_buffer_state (yyscan_t yyscanner );

static void _xkbcommon_ensure_buffer_stack (yyscan_t yyscanner );
static void _xkbcommon__load_buffer_state (yyscan_t yyscanner );
static void _xkbcommon__init_buffer (YY_BUFFER_STATE b,FILE *file ,yyscan_t yyscanner );

#define YY_FLUSH_BUFFER _xkbcommon__flush_buffer(YY_CURRENT_BUFFER ,yyscanner)

YY_BUFFER_STATE _xkbcommon__scan_buffer (char *base,yy_size_t size ,yyscan_t yyscanner );
YY_BUFFER_STATE _xkbcommon__scan_string (yyconst char *yy_str ,yyscan_t yyscanner );
YY_BUFFER_STATE _xkbcommon__scan_bytes (yyconst char *bytes,int len ,yyscan_t yyscanner );

void *_xkbcommon_alloc (yy_size_t ,yyscan_t yyscanner );
void *_xkbcommon_realloc (void *,yy_size_t ,yyscan_t yyscanner );
void _xkbcommon_free (void * ,yyscan_t yyscanner );

#define yy_new_buffer _xkbcommon__create_buffer

#define yy_set_interactive(is_interactive) \
	{ \
	if ( ! YY_CURRENT_BUFFER ){ \
        _xkbcommon_ensure_buffer_stack (yyscanner); \
		YY_CURRENT_BUFFER_LVALUE =    \
            _xkbcommon__create_buffer(yyin,YY_BUF_SIZE ,yyscanner); \
	} \
	YY_CURRENT_BUFFER_LVALUE->yy_is_interactive = is_interactive; \
	}

#define yy_set_bol(at_bol) \
	{ \
	if ( ! YY_CURRENT_BUFFER ){\
        _xkbcommon_ensure_buffer_stack (yyscanner); \
		YY_CURRENT_BUFFER_LVALUE =    \
            _xkbcommon__create_buffer(yyin,YY_BUF_SIZE ,yyscanner); \
	} \
	YY_CURRENT_BUFFER_LVALUE->yy_at_bol = at_bol; \
	}

#define YY_AT_BOL() (YY_CURRENT_BUFFER_LVALUE->yy_at_bol)

/* Begin user sect3 */

#define _xkbcommon_wrap(n) 1
#define YY_SKIP_YYWRAP

typedef unsigned char YY_CHAR;

typedef int yy_state_type;

#define yytext_ptr yytext_r

static yy_state_type yy_get_previous_state (yyscan_t yyscanner );
static yy_state_type yy_try_NUL_trans (yy_state_type current_state  ,yyscan_t yyscanner);
static int yy_get_next_buffer (yyscan_t yyscanner );
static void yy_fatal_error (yyconst char msg[] ,yyscan_t yyscanner );

/* Done after the current pattern has been matched and before the
 * corresponding action - sets up yytext.
 */
#define YY_DO_BEFORE_ACTION \
	yyg->yytext_ptr = yy_bp; \
	yyleng = (size_t) (yy_cp - yy_bp); \
	yyg->yy_hold_char = *yy_cp; \
	*yy_cp = '\0'; \
	yyg->yy_c_buf_p = yy_cp;

#define YY_NUM_RULES 83
#define YY_END_OF_BUFFER 84
/* This struct is not used in this scanner,
   but its presence is necessary. */
struct yy_trans_info
	{
	flex_int32_t yy_verify;
	flex_int32_t yy_nxt;
	};
static yyconst flex_int16_t yy_accept[336] =
    {   0,
        0,    0,    0,    0,   84,   82,   81,   81,   79,    3,
        2,   72,   73,   69,   66,   77,   67,   76,   68,   63,
       63,   78,   82,   65,   61,   61,   61,   61,   61,   61,
       61,   61,   61,   61,   61,   61,   61,   61,   61,   61,
       61,   74,   75,   70,   71,   80,   14,   83,    4,   14,
       81,    2,    1,    0,   63,    0,    0,   61,   61,   61,
       61,   61,   61,   61,   61,   61,   61,   61,   61,   61,
       61,   61,   61,   61,   61,   61,   61,   61,   61,   61,
       61,    5,    6,   10,   13,   11,    7,    9,    8,   12,
        1,   64,   62,   15,   61,   61,   61,   61,   61,   61,

       61,   61,   61,   61,   61,   61,   39,   61,   61,   61,
       61,   61,   61,   47,   61,   61,   61,   61,   61,   61,
       61,    5,   61,   61,   61,   61,   61,   61,   61,   61,
       61,   61,   61,   61,   61,   48,   54,   61,   61,   61,
       61,   61,   61,   61,   61,   61,   61,   51,   36,   61,
       61,    5,   61,   40,   61,   61,   61,   61,   61,   41,
       61,   61,   61,   61,   61,   61,   61,   61,   61,   61,
       61,   61,   61,   61,   46,   53,   61,   61,   61,   61,
       61,   61,   61,   38,   61,   61,   61,   61,   61,   34,
       61,   61,   61,   61,   61,   42,   61,   61,   61,   61,

       61,   61,   61,   61,   61,   61,   61,   61,   61,   61,
       61,   61,   61,   29,   33,   61,   27,   61,   61,   61,
       61,   43,   52,   50,   61,   32,   30,   49,   55,   61,
       61,   61,   61,   61,   61,   61,   61,   61,   61,   61,
       61,   61,   61,   28,   61,   61,   61,   61,   61,   61,
       61,   61,   61,   61,   31,   61,   45,   37,   61,   61,
       61,   61,   61,   61,   61,   61,   61,   61,   18,   61,
       61,   61,   61,   61,   61,   61,   20,   61,   61,   16,
       26,   61,   61,   61,   61,   61,   58,   61,   61,   61,
       61,   61,   61,   61,   61,   19,   61,   61,   61,   61,

       44,   61,   61,   61,   24,   17,   61,   61,   61,   59,
       57,   61,   61,   61,   25,   61,   61,   61,   61,   21,
       61,   60,   61,   61,   61,   61,   61,   56,   35,   22,
       61,   61,   61,   23,    0
    } ;

static yyconst flex_int32_t yy_ec[256] =
    {   0,
        1,    1,    1,    1,    1,    1,    1,    1,    2,    3,
        2,    1,    2,    1,    1,    1,    1,    1,    1,    1,
        1,    1,    1,    1,    1,    1,    1,    1,    1,    1,
        1,    2,    4,    5,    6,    1,    1,    1,    1,    7,
        8,    9,   10,   11,   12,   13,   14,   15,   16,   16,
       16,   16,   16,   16,   16,   17,   17,    1,   18,   19,
       20,   21,    1,    1,   22,   23,   24,   25,   26,   27,
       28,   29,   30,   31,   32,   33,   34,   35,   36,   37,
       31,   38,   39,   40,   41,   42,   43,   44,   45,   31,
       46,   47,   48,    1,   49,    1,   50,   51,   52,   53,

       54,   55,   56,   57,   58,   31,   59,   60,   61,   62,
       63,   64,   31,   65,   66,   67,   68,   69,   70,   71,
       72,   31,   73,    1,   74,   75,    1,    1,    1,    1,
        1,    1,    1,    1,    1,    1,    1,    1,    1,    1,
        1,    1,    1,    1,    1,    1,    1,    1,    1,    1,
        1,    1,    1,    1,    1,    1,    1,    1,    1,    1,
        1,    1,    1,    1,    1,    1,    1,    1,    1,    1,
        1,    1,    1,    1,    1,    1,    1,    1,    1,    1,
        1,    1,    1,    1,    1,    1,    1,    1,    1,    1,
        1,    1,    1,    1,    1,    1,    1,    1,    1,    1,

        1,    1,    1,    1,    1,    1,    1,    1,    1,    1,
        1,    1,    1,    1,    1,    1,    1,    1,    1,    1,
        1,    1,    1,    1,    1,    1,    1,    1,    1,    1,
        1,    1,    1,    1,    1,    1,    1,    1,    1,    1,
        1,    1,    1,    1,    1,    1,    1,    1,    1,    1,
        1,    1,    1,    1,    1
    } ;

static yyconst flex_int32_t yy_meta[76] =
    {   0,
        1,    1,    2,    1,    1,    1,    1,    1,    1,    3,
        1,    3,    1,    1,    4,    4,    4,    1,    1,    1,
        1,    4,    4,    4,    4,    4,    4,    5,    5,    5,
        5,    5,    5,    5,    5,    5,    5,    5,    5,    5,
        5,    5,    5,    5,    5,    1,    1,    1,    5,    4,
        4,    4,    4,    4,    4,    5,    5,    5,    5,    5,
        5,    5,    5,    5,    5,    5,    5,    5,    5,    5,
        5,    5,    1,    1,    1
    } ;

static yyconst flex_int16_t yy_base[342] =
    {   0,
        0,    0,   73,   74,  263,  695,   78,   80,  695,  695,
        0,  695,  695,  695,  695,  695,  695,  695,  203,   71,
       76,  695,    0,  695,   66,    0,   59,   54,   58,   67,
       65,   75,   67,   68,   64,   86,   83,  109,   98,   81,
       82,  695,  695,  695,  695,  695,  695,  695,  695,  158,
      114,    0,    0,  132,  138,    0,  158,    0,  100,  128,
      100,  123,  109,  124,  136,  166,  131,  141,  152,  140,
      156,  150,  157,  156,  159,  179,  171,  164,  177,  178,
      179,  221,  229,  695,  695,  695,  695,  695,  695,  695,
        0,  232,    0,  695,  192,  202,  199,  206,  200,  217,

      216,  201,  226,  220,  224,  229,  220,  222,  232,  231,
      227,  230,  238,    0,  232,  236,  244,  236,  251,  247,
      115,  279,  252,  250,  256,  263,  278,  266,  268,  272,
      284,  271,  289,  279,  296,    0,    0,  292,  298,  288,
      293,  292,  296,  305,  301,  307,  312,    0,    0,  288,
      342,  347,  305,    0,  307,  310,  315,  320,  313,    0,
      323,  335,  346,  336,  351,  348,  346,  357,  349,  364,
      357,  367,  366,  356,    0,    0,  371,  359,  371,  373,
      381,  379,  367,    0,  372,  394,  380,  383,  390,    0,
      402,  390,  394,  113,  408,    0,  399,  411,  396,  413,

      409,  417,  410,  413,  414,  413,  407,  409,  421,  424,
      423,  427,  424,    0,    0,  432,    0,  434,  448,  445,
      440,    0,    0,    0,  454,    0,    0,    0,  110,  446,
      450,  462,  453,  468,  469,  467,  472,  473,  108,  457,
      461,  477,   63,    0,  472,  485,  483,  476,  491,  474,
      482,  483,  485,  487,   61,  497,    0,    0,  485,  500,
      500,  498,  500,  518,  508,  507,  508,  516,    0,  520,
      525,  528,  519,  529,  538,  537,  538,  526,  540,    0,
        0,  539,  534,  546,  539,  534,    0,  535,  547,  556,
      566,  558,  548,  556,  575,    0,   53,  565,  563,  564,

        0,  578,  578,  587,    0,    0,  573,  581,  574,    0,
        0,  580,  583,  581,    0,  595,  586,  598,  595,    0,
      586,    0,  594,  594,  596,  602,  599,    0,    0,   49,
      612,  604,  610,    0,  695,  674,  679,  682,  684,  689,
       90
    } ;

static yyconst flex_int16_t yy_def[342] =
    {   0,
      335,    1,  336,  336,  335,  335,  335,  335,  335,  335,
      337,  335,  335,  335,  335,  335,  335,  335,  335,  335,
      335,  335,  338,  335,  339,  339,  339,  339,  339,  339,
      339,  339,  339,  339,  339,  339,  339,  339,  339,  339,
      339,  335,  335,  335,  335,  335,  335,  335,  335,  335,
      335,  337,  340,  335,  335,  341,  338,  339,  339,  339,
      339,  339,  339,  339,  339,  339,  339,  339,  339,  339,
      339,  339,  339,  339,  339,  339,  339,  339,  339,  339,
      339,  335,  335,  335,  335,  335,  335,  335,  335,  335,
      340,  335,  341,  335,  339,  339,  339,  339,  339,  339,

      339,  339,  339,  339,  339,  339,  339,  339,  339,  339,
      339,  339,  339,  339,  339,  339,  339,  339,  339,  339,
      339,  335,  339,  339,  339,  339,  339,  339,  339,  339,
      339,  339,  339,  339,  339,  339,  339,  339,  339,  339,
      339,  339,  339,  339,  339,  339,  339,  339,  339,  339,
      339,  335,  339,  339,  339,  339,  339,  339,  339,  339,
      339,  339,  339,  339,  339,  339,  339,  339,  339,  339,
      339,  339,  339,  339,  339,  339,  339,  339,  339,  339,
      339,  339,  339,  339,  339,  339,  339,  339,  339,  339,
      339,  339,  339,  339,  339,  339,  339,  339,  339,  339,

      339,  339,  339,  339,  339,  339,  339,  339,  339,  339,
      339,  339,  339,  339,  339,  339,  339,  339,  339,  339,
      339,  339,  339,  339,  339,  339,  339,  339,  339,  339,
      339,  339,  339,  339,  339,  339,  339,  339,  339,  339,
      339,  339,  339,  339,  339,  339,  339,  339,  339,  339,
      339,  339,  339,  339,  339,  339,  339,  339,  339,  339,
      339,  339,  339,  339,  339,  339,  339,  339,  339,  339,
      339,  339,  339,  339,  339,  339,  339,  339,  339,  339,
      339,  339,  339,  339,  339,  339,  339,  339,  339,  339,
      339,  339,  339,  339,  339,  339,  339,  339,  339,  339,

      339,  339,  339,  339,  339,  339,  339,  339,  339,  339,
      339,  339,  339,  339,  339,  339,  339,  339,  339,  339,
      339,  339,  339,  339,  339,  339,  339,  339,  339,  339,
      339,  339,  339,  339,    0,  335,  335,  335,  335,  335,
      335
    } ;

static yyconst flex_int16_t yy_nxt[771] =
    {   0,
        6,    7,    8,    9,   10,   11,   12,   13,   14,   15,
       16,   17,   18,   19,   20,   21,   21,   22,   23,   24,
        6,   25,   26,   26,   27,   26,   28,   29,   30,   31,
       26,   32,   33,   34,   26,   35,   36,   37,   38,   39,
       26,   40,   26,   41,   26,   42,    6,   43,   26,   25,
       26,   26,   27,   26,   28,   29,   30,   31,   32,   33,
       34,   26,   35,   36,   37,   38,   39,   26,   40,   26,
       41,   26,   44,   45,   46,   48,   48,   49,   49,   51,
       51,   51,   51,   54,   62,   55,   55,   55,   54,   59,
       55,   55,   55,   93,   63,   64,   65,  331,   60,   66,

       67,  308,   68,   69,   70,   71,   61,   72,   73,  271,
       80,  260,   62,   81,   56,   51,   51,   59,   74,   50,
       50,   63,   64,   78,   65,   60,   66,   99,   67,   68,
       69,   70,   71,   61,   75,   72,   73,   76,   80,   95,
       81,   56,   79,  101,   77,   74,   92,   92,   92,  100,
       54,   78,   55,   55,   55,   99,  256,   96,  245,  102,
      103,  220,   75,  151,   97,   76,   95,   98,  108,   79,
      101,   77,   82,   82,   83,  107,  109,  100,   94,  110,
       84,  111,  115,   85,   86,   96,  102,  112,  103,  104,
      105,   97,   87,  113,   98,   88,  108,   89,  114,   90,

      116,  121,  107,  117,  109,  106,  110,  118,   84,  111,
      115,   85,   86,  119,  112,  120,   53,  104,  105,   87,
      113,  123,   88,  124,   89,  114,   90,  125,  116,  121,
      117,  126,  106,  127,  118,  122,  122,   83,  128,  129,
      119,  130,  120,   83,   83,   83,   92,   92,   92,  123,
      131,  124,  132,  133,  134,  125,  135,  137,  136,  126,
      127,  138,  335,  141,  142,  139,  128,  129,  130,  143,
      144,  145,  146,  147,  335,  148,  149,  155,  131,  132,
      140,  133,  134,  135,  137,  136,  150,  153,  154,  138,
      141,  142,  139,  152,  152,   83,  143,  144,  145,  146,

      156,  147,  148,  157,  149,  155,  158,  159,  160,  161,
      335,  162,  163,  150,  153,  154,  164,  165,  166,  167,
      335,  168,  169,  335,  170,  172,  173,  156,  177,  171,
      174,  157,  175,  158,  159,  160,  176,  161,  162,  184,
      163,  185,  189,  164,  186,  165,  166,  167,  168,  187,
      169,  170,  188,  172,  173,  177,  171,  190,  174,  191,
      175,   83,   83,   83,  176,  178,  184,  192,  185,  179,
      189,  186,  193,  180,  181,  194,  187,  195,  197,  188,
      182,  183,  196,  198,  190,  199,  200,  191,  201,  202,
      335,  203,  204,  178,  205,  192,  206,  179,  207,  193,

      180,  181,  208,  194,  209,  195,  197,  182,  183,  196,
      198,  211,  212,  199,  200,  213,  201,  202,  203,  214,
      204,  205,  215,  210,  206,  216,  207,  217,  335,  218,
      208,  219,  209,  221,  335,  222,  223,  225,  211,  212,
      224,  226,  227,  213,  228,  229,  214,  230,  231,  215,
      210,  232,  216,  233,  234,  217,  218,  235,  219,  236,
      237,  221,  222,  238,  223,  225,  239,  224,  226,  240,
      227,  228,  229,  241,  230,  231,  242,  243,  232,  244,
      233,  234,  246,  247,  235,  248,  236,  237,  250,  251,
      238,  252,  253,  239,  257,  249,  240,  254,  255,  335,

      258,  241,  259,  242,  243,  261,  262,  244,  263,  246,
      247,  264,  265,  248,  266,  250,  267,  251,  268,  252,
      253,  257,  249,  269,  270,  254,  255,  258,  272,  273,
      259,  274,  261,  275,  262,  276,  263,  277,  264,  278,
      265,  266,  279,  267,  280,  268,  281,  282,  283,  284,
      269,  270,  285,  286,  288,  272,  273,  287,  274,  289,
      275,  290,  276,  293,  277,  294,  278,  291,  295,  297,
      279,  280,  296,  281,  282,  283,  298,  284,  299,  300,
      285,  286,  288,  301,  287,  302,  292,  289,  303,  290,
      293,  304,  305,  294,  306,  291,  295,  297,  307,  296,

      309,  310,  311,  298,  312,  299,  300,  313,  314,  318,
      301,  315,  316,  302,  317,  319,  303,  320,  304,  305,
      321,  306,  322,  323,  324,  333,  307,  309,  310,  311,
      325,  326,  312,  327,  328,  313,  314,  318,  315,  316,
      329,  317,  319,  330,  320,  332,  334,  335,  321,  322,
      335,  323,  324,  333,  335,  335,  335,  325,  326,  335,
      327,  328,  335,  335,  335,  335,  335,  329,  335,  335,
      330,  335,  332,  334,   47,   47,   47,   47,   47,   52,
      335,   52,   52,   52,   57,   57,   57,   58,   58,   91,
      335,   91,   91,   91,    5,  335,  335,  335,  335,  335,

      335,  335,  335,  335,  335,  335,  335,  335,  335,  335,
      335,  335,  335,  335,  335,  335,  335,  335,  335,  335,
      335,  335,  335,  335,  335,  335,  335,  335,  335,  335,
      335,  335,  335,  335,  335,  335,  335,  335,  335,  335,
      335,  335,  335,  335,  335,  335,  335,  335,  335,  335,
      335,  335,  335,  335,  335,  335,  335,  335,  335,  335,
      335,  335,  335,  335,  335,  335,  335,  335,  335,  335
    } ;

static yyconst flex_int16_t yy_chk[771] =
    {   0,
        1,    1,    1,    1,    1,    1,    1,    1,    1,    1,
        1,    1,    1,    1,    1,    1,    1,    1,    1,    1,
        1,    1,    1,    1,    1,    1,    1,    1,    1,    1,
        1,    1,    1,    1,    1,    1,    1,    1,    1,    1,
        1,    1,    1,    1,    1,    1,    1,    1,    1,    1,
        1,    1,    1,    1,    1,    1,    1,    1,    1,    1,
        1,    1,    1,    1,    1,    1,    1,    1,    1,    1,
        1,    1,    1,    1,    1,    3,    4,    3,    4,    7,
        7,    8,    8,   20,   27,   20,   20,   20,   21,   25,
       21,   21,   21,  341,   28,   29,   30,  330,   25,   31,

       32,  297,   33,   34,   35,   35,   25,   36,   37,  255,
       40,  243,   27,   41,   20,   51,   51,   25,   37,    3,
        4,   28,   29,   39,   30,   25,   31,   61,   32,   33,
       34,   35,   35,   25,   38,   36,   37,   38,   40,   59,
       41,   20,   39,   63,   38,   37,   54,   54,   54,   62,
       55,   39,   55,   55,   55,   61,  239,   60,  229,   64,
       65,  194,   38,  121,   60,   38,   59,   60,   68,   39,
       63,   38,   50,   50,   50,   67,   69,   62,   57,   70,
       50,   71,   75,   50,   50,   60,   64,   72,   65,   66,
       66,   60,   50,   73,   60,   50,   68,   50,   74,   50,

       76,   81,   67,   77,   69,   66,   70,   78,   50,   71,
       75,   50,   50,   79,   72,   80,   19,   66,   66,   50,
       73,   95,   50,   96,   50,   74,   50,   97,   76,   81,
       77,   98,   66,   99,   78,   82,   82,   82,  100,  101,
       79,  102,   80,   83,   83,   83,   92,   92,   92,   95,
      103,   96,  104,  105,  106,   97,  107,  108,  107,   98,
       99,  109,    5,  110,  111,  109,  100,  101,  102,  112,
      113,  115,  116,  117,    0,  118,  119,  125,  103,  104,
      109,  105,  106,  107,  108,  107,  120,  123,  124,  109,
      110,  111,  109,  122,  122,  122,  112,  113,  115,  116,

      126,  117,  118,  127,  119,  125,  128,  129,  130,  131,
        0,  132,  133,  120,  123,  124,  134,  135,  138,  139,
        0,  140,  141,    0,  142,  143,  144,  126,  150,  142,
      145,  127,  146,  128,  129,  130,  147,  131,  132,  153,
      133,  155,  159,  134,  156,  135,  138,  139,  140,  157,
      141,  142,  158,  143,  144,  150,  142,  161,  145,  162,
      146,  152,  152,  152,  147,  151,  153,  163,  155,  151,
      159,  156,  164,  151,  151,  165,  157,  166,  168,  158,
      151,  151,  167,  169,  161,  170,  171,  162,  172,  173,
        0,  174,  177,  151,  178,  163,  179,  151,  180,  164,

      151,  151,  181,  165,  182,  166,  168,  151,  151,  167,
      169,  183,  185,  170,  171,  186,  172,  173,  174,  187,
      177,  178,  188,  182,  179,  189,  180,  191,    0,  192,
      181,  193,  182,  195,    0,  197,  198,  200,  183,  185,
      199,  201,  202,  186,  203,  204,  187,  205,  206,  188,
      182,  207,  189,  208,  209,  191,  192,  210,  193,  211,
      212,  195,  197,  213,  198,  200,  216,  199,  201,  218,
      202,  203,  204,  219,  205,  206,  220,  221,  207,  225,
      208,  209,  230,  231,  210,  232,  211,  212,  233,  234,
      213,  235,  236,  216,  240,  232,  218,  237,  238,    0,

      241,  219,  242,  220,  221,  245,  246,  225,  247,  230,
      231,  248,  249,  232,  250,  233,  251,  234,  252,  235,
      236,  240,  232,  253,  254,  237,  238,  241,  256,  259,
      242,  260,  245,  260,  246,  261,  247,  262,  248,  263,
      249,  250,  264,  251,  265,  252,  266,  267,  268,  270,
      253,  254,  271,  272,  274,  256,  259,  273,  260,  275,
      260,  276,  261,  278,  262,  279,  263,  277,  282,  284,
      264,  265,  283,  266,  267,  268,  285,  270,  286,  288,
      271,  272,  274,  289,  273,  290,  277,  275,  291,  276,
      278,  292,  293,  279,  294,  277,  282,  284,  295,  283,

      298,  299,  300,  285,  302,  286,  288,  303,  304,  312,
      289,  307,  308,  290,  309,  313,  291,  314,  292,  293,
      316,  294,  317,  318,  319,  332,  295,  298,  299,  300,
      321,  323,  302,  324,  325,  303,  304,  312,  307,  308,
      326,  309,  313,  327,  314,  331,  333,    0,  316,  317,
        0,  318,  319,  332,    0,    0,    0,  321,  323,    0,
      324,  325,    0,    0,    0,    0,    0,  326,    0,    0,
      327,    0,  331,  333,  336,  336,  336,  336,  336,  337,
        0,  337,  337,  337,  338,  338,  338,  339,  339,  340,
        0,  340,  340,  340,  335,  335,  335,  335,  335,  335,

      335,  335,  335,  335,  335,  335,  335,  335,  335,  335,
      335,  335,  335,  335,  335,  335,  335,  335,  335,  335,
      335,  335,  335,  335,  335,  335,  335,  335,  335,  335,
      335,  335,  335,  335,  335,  335,  335,  335,  335,  335,
      335,  335,  335,  335,  335,  335,  335,  335,  335,  335,
      335,  335,  335,  335,  335,  335,  335,  335,  335,  335,
      335,  335,  335,  335,  335,  335,  335,  335,  335,  335
    } ;

/* Table of booleans, true if rule could match eol. */
static yyconst flex_int32_t yy_rule_can_match_eol[84] =
    {   0,
0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 
    0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 
    0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 
    0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 
    0, 1, 0, 0,     };

/* The intent behind this definition is that it'll catch
 * any uses of REJECT which flex missed.
 */
#define REJECT reject_used_but_not_detected
#define yymore() yymore_used_but_not_detected
#define YY_MORE_ADJ 0
#define YY_RESTORE_YY_MORE_OFFSET
#line 1 "scanner.l"
/************************************************************
 Copyright (c) 1994 by Silicon Graphics Computer Systems, Inc.

 Permission to use, copy, modify, and distribute this
 software and its documentation for any purpose and without
 fee is hereby granted, provided that the above copyright
 notice appear in all copies and that both that copyright
 notice and this permission notice appear in supporting
 documentation, and that the name of Silicon Graphics not be
 used in advertising or publicity pertaining to distribution
 of the software without specific prior written permission.
 Silicon Graphics makes no representation about the suitability
 of this software for any purpose. It is provided "as is"
 without any express or implied warranty.

 SILICON GRAPHICS DISCLAIMS ALL WARRANTIES WITH REGARD TO THIS
 SOFTWARE, INCLUDING ALL IMPLIED WARRANTIES OF MERCHANTABILITY
 AND FITNESS FOR A PARTICULAR PURPOSE. IN NO EVENT SHALL SILICON
 GRAPHICS BE LIABLE FOR ANY SPECIAL, INDIRECT OR CONSEQUENTIAL
 DAMAGES OR ANY DAMAGES WHATSOEVER RESULTING FROM LOSS OF USE,
 DATA OR PROFITS, WHETHER IN AN ACTION OF CONTRACT, NEGLIGENCE
 OR OTHER TORTIOUS ACTION, ARISING OUT OF OR IN CONNECTION  WITH
 THE USE OR PERFORMANCE OF THIS SOFTWARE.

 ********************************************************/
#line 28 "scanner.l"
#include "xkbcomp-priv.h"
#include "parser-priv.h"

#pragma GCC diagnostic ignored "-Wmissing-noreturn"
#pragma GCC diagnostic ignored "-Wredundant-decls"
#pragma GCC diagnostic push

struct scanner_extra {
    struct xkb_context *ctx;
    const char *file_name;
    char scanBuf[1024];
    char *s;
};

static void
scanner_error_extra(struct YYLTYPE *loc, struct scanner_extra *extra,
                    const char *msg);

#define YY_USER_ACTION {                \
        yylloc->first_line = yylineno;  \
        yylloc->last_line = yylineno;   \
}

#define APPEND_S(ch) do {                                               \
    if (yyextra->s - yyextra->scanBuf >= sizeof(yyextra->scanBuf) - 1)  \
        return ERROR_TOK;                                               \
    *yyextra->s++ = ch;                                                 \
} while (0)
#define YY_NO_UNISTD_H 1
#define YY_NO_INPUT 1

#line 803 "src/xkbcomp/scanner.c"

#define INITIAL 0
#define S_STR 1

#ifndef YY_NO_UNISTD_H
/* Special case for "unistd.h", since it is non-ANSI. We include it way
 * down here because we want the user's section 1 to have been scanned first.
 * The user has a chance to override it with an option.
 */
#include <unistd.h>
#endif

#define YY_EXTRA_TYPE struct scanner_extra *

/* Holds the entire state of the reentrant scanner. */
struct yyguts_t
    {

    /* User-defined. Not touched by flex. */
    YY_EXTRA_TYPE yyextra_r;

    /* The rest are the same as the globals declared in the non-reentrant scanner. */
    FILE *yyin_r, *yyout_r;
    size_t yy_buffer_stack_top; /**< index of top of stack. */
    size_t yy_buffer_stack_max; /**< capacity of stack. */
    YY_BUFFER_STATE * yy_buffer_stack; /**< Stack as an array. */
    char yy_hold_char;
    int yy_n_chars;
    int yyleng_r;
    char *yy_c_buf_p;
    int yy_init;
    int yy_start;
    int yy_did_buffer_switch_on_eof;
    int yy_start_stack_ptr;
    int yy_start_stack_depth;
    int *yy_start_stack;
    yy_state_type yy_last_accepting_state;
    char* yy_last_accepting_cpos;

    int yylineno_r;
    int yy_flex_debug_r;

    char *yytext_r;
    int yy_more_flag;
    int yy_more_len;

    YYSTYPE * yylval_r;

    YYLTYPE * yylloc_r;

    }; /* end struct yyguts_t */

static int yy_init_globals (yyscan_t yyscanner );

    /* This must go here because YYSTYPE and YYLTYPE are included
     * from bison output in section 1.*/
    #    define yylval yyg->yylval_r
    
    #    define yylloc yyg->yylloc_r
    
int _xkbcommon_lex_init (yyscan_t* scanner);

int _xkbcommon_lex_init_extra (YY_EXTRA_TYPE user_defined,yyscan_t* scanner);

/* Accessor methods to globals.
   These are made visible to non-reentrant scanners for convenience. */

int _xkbcommon_lex_destroy (yyscan_t yyscanner );

int _xkbcommon_get_debug (yyscan_t yyscanner );

void _xkbcommon_set_debug (int debug_flag ,yyscan_t yyscanner );

YY_EXTRA_TYPE _xkbcommon_get_extra (yyscan_t yyscanner );

void _xkbcommon_set_extra (YY_EXTRA_TYPE user_defined ,yyscan_t yyscanner );

FILE *_xkbcommon_get_in (yyscan_t yyscanner );

void _xkbcommon_set_in  (FILE * in_str ,yyscan_t yyscanner );

FILE *_xkbcommon_get_out (yyscan_t yyscanner );

void _xkbcommon_set_out  (FILE * out_str ,yyscan_t yyscanner );

int _xkbcommon_get_leng (yyscan_t yyscanner );

char *_xkbcommon_get_text (yyscan_t yyscanner );

int _xkbcommon_get_lineno (yyscan_t yyscanner );

void _xkbcommon_set_lineno (int line_number ,yyscan_t yyscanner );

YYSTYPE * _xkbcommon_get_lval (yyscan_t yyscanner );

void _xkbcommon_set_lval (YYSTYPE * yylval_param ,yyscan_t yyscanner );

       YYLTYPE *_xkbcommon_get_lloc (yyscan_t yyscanner );
    
        void _xkbcommon_set_lloc (YYLTYPE * yylloc_param ,yyscan_t yyscanner );
    
/* Macros after this point can all be overridden by user definitions in
 * section 1.
 */

#ifndef YY_SKIP_YYWRAP
#ifdef __cplusplus
extern "C" int _xkbcommon_wrap (yyscan_t yyscanner );
#else
extern int _xkbcommon_wrap (yyscan_t yyscanner );
#endif
#endif

#ifndef yytext_ptr
static void yy_flex_strncpy (char *,yyconst char *,int ,yyscan_t yyscanner);
#endif

#ifdef YY_NEED_STRLEN
static int yy_flex_strlen (yyconst char * ,yyscan_t yyscanner);
#endif

#ifndef YY_NO_INPUT

#ifdef __cplusplus
static int yyinput (yyscan_t yyscanner );
#else
static int input (yyscan_t yyscanner );
#endif

#endif

/* Amount of stuff to slurp up with each read. */
#ifndef YY_READ_BUF_SIZE
#ifdef __ia64__
/* On IA-64, the buffer size is 16k, not 8k */
#define YY_READ_BUF_SIZE 16384
#else
#define YY_READ_BUF_SIZE 8192
#endif /* __ia64__ */
#endif

/* Copy whatever the last rule matched to the standard output. */
#ifndef ECHO
/* This used to be an fputs(), but since the string might contain NUL's,
 * we now use fwrite().
 */
#define ECHO do { if (fwrite( yytext, yyleng, 1, yyout )) {} } while (0)
#endif

/* Gets input and stuffs it into "buf".  number of characters read, or YY_NULL,
 * is returned in "result".
 */
#ifndef YY_INPUT
#define YY_INPUT(buf,result,max_size) \
	if ( YY_CURRENT_BUFFER_LVALUE->yy_is_interactive ) \
		{ \
		int c = '*'; \
		size_t n; \
		for ( n = 0; n < max_size && \
			     (c = getc( yyin )) != EOF && c != '\n'; ++n ) \
			buf[n] = (char) c; \
		if ( c == '\n' ) \
			buf[n++] = (char) c; \
		if ( c == EOF && ferror( yyin ) ) \
			YY_FATAL_ERROR( "input in flex scanner failed" ); \
		result = n; \
		} \
	else \
		{ \
		errno=0; \
		while ( (result = fread(buf, 1, max_size, yyin))==0 && ferror(yyin)) \
			{ \
			if( errno != EINTR) \
				{ \
				YY_FATAL_ERROR( "input in flex scanner failed" ); \
				break; \
				} \
			errno=0; \
			clearerr(yyin); \
			} \
		}\
\

#endif

/* No semi-colon after return; correct usage is to write "yyterminate();" -
 * we don't want an extra ';' after the "return" because that will cause
 * some compilers to complain about unreachable statements.
 */
#ifndef yyterminate
#define yyterminate() return YY_NULL
#endif

/* Number of entries by which start-condition stack grows. */
#ifndef YY_START_STACK_INCR
#define YY_START_STACK_INCR 25
#endif

/* Report a fatal error. */
#ifndef YY_FATAL_ERROR
#define YY_FATAL_ERROR(msg) yy_fatal_error( msg , yyscanner)
#endif

/* end tables serialization structures and prototypes */

/* Default declaration of generated scanner - a define so the user can
 * easily add parameters.
 */
#ifndef YY_DECL
#define YY_DECL_IS_OURS 1

extern int _xkbcommon_lex \
               (YYSTYPE * yylval_param,YYLTYPE * yylloc_param ,yyscan_t yyscanner);

#define YY_DECL int _xkbcommon_lex \
               (YYSTYPE * yylval_param, YYLTYPE * yylloc_param , yyscan_t yyscanner)
#endif /* !YY_DECL */

/* Code executed at the beginning of each rule, after yytext and yyleng
 * have been set up.
 */
#ifndef YY_USER_ACTION
#define YY_USER_ACTION
#endif

/* Code executed at the end of each rule. */
#ifndef YY_BREAK
#define YY_BREAK break;
#endif

#define YY_RULE_SETUP \
	YY_USER_ACTION

/** The main scanner function which does all the work.
 */
YY_DECL
{
	register yy_state_type yy_current_state;
	register char *yy_cp, *yy_bp;
	register int yy_act;
    struct yyguts_t * yyg = (struct yyguts_t*)yyscanner;

#line 69 "scanner.l"


#line 1049 "src/xkbcomp/scanner.c"

    yylval = yylval_param;

    yylloc = yylloc_param;

	if ( !yyg->yy_init )
		{
		yyg->yy_init = 1;

#ifdef YY_USER_INIT
		YY_USER_INIT;
#endif

		if ( ! yyg->yy_start )
			yyg->yy_start = 1;	/* first start state */

		if ( ! yyin )
			yyin = stdin;

		if ( ! yyout )
			yyout = stdout;

		if ( ! YY_CURRENT_BUFFER ) {
			_xkbcommon_ensure_buffer_stack (yyscanner);
			YY_CURRENT_BUFFER_LVALUE =
				_xkbcommon__create_buffer(yyin,YY_BUF_SIZE ,yyscanner);
		}

		_xkbcommon__load_buffer_state(yyscanner );
		}

	while ( 1 )		/* loops until end-of-file is reached */
		{
		yy_cp = yyg->yy_c_buf_p;

		/* Support of yytext. */
		*yy_cp = yyg->yy_hold_char;

		/* yy_bp points to the position in yy_ch_buf of the start of
		 * the current run.
		 */
		yy_bp = yy_cp;

		yy_current_state = yyg->yy_start;
yy_match:
		do
			{
			register YY_CHAR yy_c = yy_ec[YY_SC_TO_UI(*yy_cp)];
			if ( yy_accept[yy_current_state] )
				{
				yyg->yy_last_accepting_state = yy_current_state;
				yyg->yy_last_accepting_cpos = yy_cp;
				}
			while ( yy_chk[yy_base[yy_current_state] + yy_c] != yy_current_state )
				{
				yy_current_state = (int) yy_def[yy_current_state];
				if ( yy_current_state >= 336 )
					yy_c = yy_meta[(unsigned int) yy_c];
				}
			yy_current_state = yy_nxt[yy_base[yy_current_state] + (unsigned int) yy_c];
			++yy_cp;
			}
		while ( yy_current_state != 335 );
		yy_cp = yyg->yy_last_accepting_cpos;
		yy_current_state = yyg->yy_last_accepting_state;

yy_find_action:
		yy_act = yy_accept[yy_current_state];

		YY_DO_BEFORE_ACTION;

		if ( yy_act != YY_END_OF_BUFFER && yy_rule_can_match_eol[yy_act] )
			{
			int yyl;
			for ( yyl = 0; yyl < yyleng; ++yyl )
				if ( yytext[yyl] == '\n' )
					   
    do{ yylineno++;
        yycolumn=0;
    }while(0)
;
			}

do_action:	/* This label is used only to access EOF actions. */

		switch ( yy_act )
	{ /* beginning of action switch */
			case 0: /* must back up */
			/* undo the effects of YY_DO_BEFORE_ACTION */
			*yy_cp = yyg->yy_hold_char;
			yy_cp = yyg->yy_last_accepting_cpos;
			yy_current_state = yyg->yy_last_accepting_state;
			goto yy_find_action;

case 1:
YY_RULE_SETUP
#line 71 "scanner.l"

	YY_BREAK
case 2:
YY_RULE_SETUP
#line 72 "scanner.l"

	YY_BREAK
case 3:
YY_RULE_SETUP
#line 74 "scanner.l"
yyextra->s = yyextra->scanBuf; BEGIN(S_STR);
	YY_BREAK
case 4:
YY_RULE_SETUP
#line 76 "scanner.l"
{
                        BEGIN(INITIAL);
                        *yyextra->s = '\0';
                        yylval->str = strdup(yyextra->scanBuf);
                        return STRING;
                    }
	YY_BREAK
case 5:
YY_RULE_SETUP
#line 83 "scanner.l"
{
                        /* octal escape sequence */
                        unsigned int result;

                        (void) sscanf( yytext + 1, "%o", &result );

                        if (result > 0xff) {
                            scanner_error_extra(yylloc, yyextra,
                                                "Illegal octal escape");
                            return ERROR_TOK;
                        }

                        APPEND_S(result);
                    }
	YY_BREAK
case 6:
YY_RULE_SETUP
#line 98 "scanner.l"
{
                        scanner_error_extra(yylloc, yyextra,
                                            "Illegal octal escape");
                        return ERROR_TOK;
                    }
	YY_BREAK
case 7:
YY_RULE_SETUP
#line 104 "scanner.l"
APPEND_S('\n');
	YY_BREAK
case 8:
YY_RULE_SETUP
#line 105 "scanner.l"
APPEND_S('\t');
	YY_BREAK
case 9:
YY_RULE_SETUP
#line 106 "scanner.l"
APPEND_S('\r');
	YY_BREAK
case 10:
YY_RULE_SETUP
#line 107 "scanner.l"
APPEND_S('\b');
	YY_BREAK
case 11:
YY_RULE_SETUP
#line 108 "scanner.l"
APPEND_S('\f');
	YY_BREAK
case 12:
YY_RULE_SETUP
#line 109 "scanner.l"
APPEND_S('\v');
	YY_BREAK
case 13:
YY_RULE_SETUP
#line 110 "scanner.l"
APPEND_S('\033');
	YY_BREAK
case 14:
YY_RULE_SETUP
#line 112 "scanner.l"
APPEND_S(yytext[0]);
	YY_BREAK
case 15:
YY_RULE_SETUP
#line 114 "scanner.l"
{
                        /* We don't want the brackets. */
                        yytext[yyleng - 1] = '\0';
                        yytext++;
                        yylval->sval = xkb_atom_intern(yyextra->ctx, yytext);
                        return KEYNAME;
                    }
	YY_BREAK
case 16:
YY_RULE_SETUP
#line 122 "scanner.l"
return XKB_KEYMAP;
	YY_BREAK
case 17:
YY_RULE_SETUP
#line 123 "scanner.l"
return XKB_KEYCODES;
	YY_BREAK
case 18:
YY_RULE_SETUP
#line 124 "scanner.l"
return XKB_TYPES;
	YY_BREAK
case 19:
YY_RULE_SETUP
#line 125 "scanner.l"
return XKB_SYMBOLS;
	YY_BREAK
case 20:
YY_RULE_SETUP
#line 126 "scanner.l"
return XKB_COMPATMAP;
	YY_BREAK
case 21:
YY_RULE_SETUP
#line 127 "scanner.l"
return XKB_COMPATMAP;
	YY_BREAK
case 22:
YY_RULE_SETUP
#line 128 "scanner.l"
return XKB_COMPATMAP;
	YY_BREAK
case 23:
YY_RULE_SETUP
#line 129 "scanner.l"
return XKB_COMPATMAP;
	YY_BREAK
case 24:
YY_RULE_SETUP
#line 130 "scanner.l"
return XKB_GEOMETRY;
	YY_BREAK
case 25:
YY_RULE_SETUP
#line 131 "scanner.l"
return XKB_SEMANTICS;
	YY_BREAK
case 26:
YY_RULE_SETUP
#line 132 "scanner.l"
return XKB_LAYOUT;
	YY_BREAK
case 27:
YY_RULE_SETUP
#line 133 "scanner.l"
return INCLUDE;
	YY_BREAK
case 28:
YY_RULE_SETUP
#line 134 "scanner.l"
return OVERRIDE;
	YY_BREAK
case 29:
YY_RULE_SETUP
#line 135 "scanner.l"
return AUGMENT;
	YY_BREAK
case 30:
YY_RULE_SETUP
#line 136 "scanner.l"
return REPLACE;
	YY_BREAK
case 31:
YY_RULE_SETUP
#line 137 "scanner.l"
return ALTERNATE;
	YY_BREAK
case 32:
YY_RULE_SETUP
#line 138 "scanner.l"
return PARTIAL;
	YY_BREAK
case 33:
YY_RULE_SETUP
#line 139 "scanner.l"
return DEFAULT;
	YY_BREAK
case 34:
YY_RULE_SETUP
#line 140 "scanner.l"
return HIDDEN;
	YY_BREAK
case 35:
YY_RULE_SETUP
#line 141 "scanner.l"
return VIRTUAL_MODS;
	YY_BREAK
case 36:
YY_RULE_SETUP
#line 142 "scanner.l"
return TYPE;
	YY_BREAK
case 37:
YY_RULE_SETUP
#line 143 "scanner.l"
return INTERPRET;
	YY_BREAK
case 38:
YY_RULE_SETUP
#line 144 "scanner.l"
return ACTION_TOK;
	YY_BREAK
case 39:
YY_RULE_SETUP
#line 145 "scanner.l"
return KEY;
	YY_BREAK
case 40:
YY_RULE_SETUP
#line 146 "scanner.l"
return ALIAS;
	YY_BREAK
case 41:
YY_RULE_SETUP
#line 147 "scanner.l"
return GROUP;
	YY_BREAK
case 42:
YY_RULE_SETUP
#line 148 "scanner.l"
return MODIFIER_MAP;
	YY_BREAK
case 43:
YY_RULE_SETUP
#line 149 "scanner.l"
return MODIFIER_MAP;
	YY_BREAK
case 44:
YY_RULE_SETUP
#line 150 "scanner.l"
return MODIFIER_MAP;
	YY_BREAK
case 45:
YY_RULE_SETUP
#line 151 "scanner.l"
return INDICATOR;
	YY_BREAK
case 46:
YY_RULE_SETUP
#line 152 "scanner.l"
return SHAPE;
	YY_BREAK
case 47:
YY_RULE_SETUP
#line 153 "scanner.l"
return ROW;
	YY_BREAK
case 48:
YY_RULE_SETUP
#line 154 "scanner.l"
return KEYS;
	YY_BREAK
case 49:
YY_RULE_SETUP
#line 155 "scanner.l"
return SECTION;
	YY_BREAK
case 50:
YY_RULE_SETUP
#line 156 "scanner.l"
return OVERLAY;
	YY_BREAK
case 51:
YY_RULE_SETUP
#line 157 "scanner.l"
return TEXT;
	YY_BREAK
case 52:
YY_RULE_SETUP
#line 158 "scanner.l"
return OUTLINE;
	YY_BREAK
case 53:
YY_RULE_SETUP
#line 159 "scanner.l"
return SOLID;
	YY_BREAK
case 54:
YY_RULE_SETUP
#line 160 "scanner.l"
return LOGO;
	YY_BREAK
case 55:
YY_RULE_SETUP
#line 161 "scanner.l"
return VIRTUAL;
	YY_BREAK
case 56:
YY_RULE_SETUP
#line 162 "scanner.l"
return ALPHANUMERIC_KEYS;
	YY_BREAK
case 57:
YY_RULE_SETUP
#line 163 "scanner.l"
return MODIFIER_KEYS;
	YY_BREAK
case 58:
YY_RULE_SETUP
#line 164 "scanner.l"
return KEYPAD_KEYS;
	YY_BREAK
case 59:
YY_RULE_SETUP
#line 165 "scanner.l"
return FUNCTION_KEYS;
	YY_BREAK
case 60:
YY_RULE_SETUP
#line 166 "scanner.l"
return ALTERNATE_GROUP;
	YY_BREAK
case 61:
YY_RULE_SETUP
#line 168 "scanner.l"
yylval->str = strdup(yytext); return IDENT;
	YY_BREAK
case 62:
#line 171 "scanner.l"
case 63:
YY_RULE_SETUP
#line 171 "scanner.l"
{
                            char *end;
                            yylval->num = strtoul(yytext, &end, 0);

                            return INTEGER;
                        }
	YY_BREAK
case 64:
YY_RULE_SETUP
#line 177 "scanner.l"
{
                            char *end;
                            yylval->num = strtod(yytext, &end);

                            return FLOAT;
                        }
	YY_BREAK
case 65:
YY_RULE_SETUP
#line 184 "scanner.l"
return EQUALS;
	YY_BREAK
case 66:
YY_RULE_SETUP
#line 185 "scanner.l"
return PLUS;
	YY_BREAK
case 67:
YY_RULE_SETUP
#line 186 "scanner.l"
return MINUS;
	YY_BREAK
case 68:
YY_RULE_SETUP
#line 187 "scanner.l"
return DIVIDE;
	YY_BREAK
case 69:
YY_RULE_SETUP
#line 188 "scanner.l"
return TIMES;
	YY_BREAK
case 70:
YY_RULE_SETUP
#line 189 "scanner.l"
return OBRACE;
	YY_BREAK
case 71:
YY_RULE_SETUP
#line 190 "scanner.l"
return CBRACE;
	YY_BREAK
case 72:
YY_RULE_SETUP
#line 191 "scanner.l"
return OPAREN;
	YY_BREAK
case 73:
YY_RULE_SETUP
#line 192 "scanner.l"
return CPAREN;
	YY_BREAK
case 74:
YY_RULE_SETUP
#line 193 "scanner.l"
return OBRACKET;
	YY_BREAK
case 75:
YY_RULE_SETUP
#line 194 "scanner.l"
return CBRACKET;
	YY_BREAK
case 76:
YY_RULE_SETUP
#line 195 "scanner.l"
return DOT;
	YY_BREAK
case 77:
YY_RULE_SETUP
#line 196 "scanner.l"
return COMMA;
	YY_BREAK
case 78:
YY_RULE_SETUP
#line 197 "scanner.l"
return SEMI;
	YY_BREAK
case 79:
YY_RULE_SETUP
#line 198 "scanner.l"
return EXCLAM;
	YY_BREAK
case 80:
YY_RULE_SETUP
#line 199 "scanner.l"
return INVERT;
	YY_BREAK
case 81:
/* rule 81 can match eol */
YY_RULE_SETUP
#line 201 "scanner.l"

	YY_BREAK
case YY_STATE_EOF(INITIAL):
case YY_STATE_EOF(S_STR):
#line 203 "scanner.l"
return END_OF_FILE;
	YY_BREAK
case 82:
YY_RULE_SETUP
#line 205 "scanner.l"
return ERROR_TOK;
	YY_BREAK
case 83:
YY_RULE_SETUP
#line 207 "scanner.l"
ECHO;
	YY_BREAK
#line 1600 "src/xkbcomp/scanner.c"

	case YY_END_OF_BUFFER:
		{
		/* Amount of text matched not including the EOB char. */
		int yy_amount_of_matched_text = (int) (yy_cp - yyg->yytext_ptr) - 1;

		/* Undo the effects of YY_DO_BEFORE_ACTION. */
		*yy_cp = yyg->yy_hold_char;
		YY_RESTORE_YY_MORE_OFFSET

		if ( YY_CURRENT_BUFFER_LVALUE->yy_buffer_status == YY_BUFFER_NEW )
			{
			/* We're scanning a new file or input source.  It's
			 * possible that this happened because the user
			 * just pointed yyin at a new source and called
			 * _xkbcommon_lex().  If so, then we have to assure
			 * consistency between YY_CURRENT_BUFFER and our
			 * globals.  Here is the right place to do so, because
			 * this is the first action (other than possibly a
			 * back-up) that will match for the new input source.
			 */
			yyg->yy_n_chars = YY_CURRENT_BUFFER_LVALUE->yy_n_chars;
			YY_CURRENT_BUFFER_LVALUE->yy_input_file = yyin;
			YY_CURRENT_BUFFER_LVALUE->yy_buffer_status = YY_BUFFER_NORMAL;
			}

		/* Note that here we test for yy_c_buf_p "<=" to the position
		 * of the first EOB in the buffer, since yy_c_buf_p will
		 * already have been incremented past the NUL character
		 * (since all states make transitions on EOB to the
		 * end-of-buffer state).  Contrast this with the test
		 * in input().
		 */
		if ( yyg->yy_c_buf_p <= &YY_CURRENT_BUFFER_LVALUE->yy_ch_buf[yyg->yy_n_chars] )
			{ /* This was really a NUL. */
			yy_state_type yy_next_state;

			yyg->yy_c_buf_p = yyg->yytext_ptr + yy_amount_of_matched_text;

			yy_current_state = yy_get_previous_state( yyscanner );

			/* Okay, we're now positioned to make the NUL
			 * transition.  We couldn't have
			 * yy_get_previous_state() go ahead and do it
			 * for us because it doesn't know how to deal
			 * with the possibility of jamming (and we don't
			 * want to build jamming into it because then it
			 * will run more slowly).
			 */

			yy_next_state = yy_try_NUL_trans( yy_current_state , yyscanner);

			yy_bp = yyg->yytext_ptr + YY_MORE_ADJ;

			if ( yy_next_state )
				{
				/* Consume the NUL. */
				yy_cp = ++yyg->yy_c_buf_p;
				yy_current_state = yy_next_state;
				goto yy_match;
				}

			else
				{
				yy_cp = yyg->yy_last_accepting_cpos;
				yy_current_state = yyg->yy_last_accepting_state;
				goto yy_find_action;
				}
			}

		else switch ( yy_get_next_buffer( yyscanner ) )
			{
			case EOB_ACT_END_OF_FILE:
				{
				yyg->yy_did_buffer_switch_on_eof = 0;

				if ( _xkbcommon_wrap(yyscanner ) )
					{
					/* Note: because we've taken care in
					 * yy_get_next_buffer() to have set up
					 * yytext, we can now set up
					 * yy_c_buf_p so that if some total
					 * hoser (like flex itself) wants to
					 * call the scanner after we return the
					 * YY_NULL, it'll still work - another
					 * YY_NULL will get returned.
					 */
					yyg->yy_c_buf_p = yyg->yytext_ptr + YY_MORE_ADJ;

					yy_act = YY_STATE_EOF(YY_START);
					goto do_action;
					}

				else
					{
					if ( ! yyg->yy_did_buffer_switch_on_eof )
						YY_NEW_FILE;
					}
				break;
				}

			case EOB_ACT_CONTINUE_SCAN:
				yyg->yy_c_buf_p =
					yyg->yytext_ptr + yy_amount_of_matched_text;

				yy_current_state = yy_get_previous_state( yyscanner );

				yy_cp = yyg->yy_c_buf_p;
				yy_bp = yyg->yytext_ptr + YY_MORE_ADJ;
				goto yy_match;

			case EOB_ACT_LAST_MATCH:
				yyg->yy_c_buf_p =
				&YY_CURRENT_BUFFER_LVALUE->yy_ch_buf[yyg->yy_n_chars];

				yy_current_state = yy_get_previous_state( yyscanner );

				yy_cp = yyg->yy_c_buf_p;
				yy_bp = yyg->yytext_ptr + YY_MORE_ADJ;
				goto yy_find_action;
			}
		break;
		}

	default:
		YY_FATAL_ERROR(
			"fatal flex scanner internal error--no action found" );
	} /* end of action switch */
		} /* end of scanning one token */
} /* end of _xkbcommon_lex */

/* yy_get_next_buffer - try to read in a new buffer
 *
 * Returns a code representing an action:
 *	EOB_ACT_LAST_MATCH -
 *	EOB_ACT_CONTINUE_SCAN - continue scanning from current position
 *	EOB_ACT_END_OF_FILE - end of file
 */
static int yy_get_next_buffer (yyscan_t yyscanner)
{
    struct yyguts_t * yyg = (struct yyguts_t*)yyscanner;
	register char *dest = YY_CURRENT_BUFFER_LVALUE->yy_ch_buf;
	register char *source = yyg->yytext_ptr;
	register int number_to_move, i;
	int ret_val;

	if ( yyg->yy_c_buf_p > &YY_CURRENT_BUFFER_LVALUE->yy_ch_buf[yyg->yy_n_chars + 1] )
		YY_FATAL_ERROR(
		"fatal flex scanner internal error--end of buffer missed" );

	if ( YY_CURRENT_BUFFER_LVALUE->yy_fill_buffer == 0 )
		{ /* Don't try to fill the buffer, so this is an EOF. */
		if ( yyg->yy_c_buf_p - yyg->yytext_ptr - YY_MORE_ADJ == 1 )
			{
			/* We matched a single character, the EOB, so
			 * treat this as a final EOF.
			 */
			return EOB_ACT_END_OF_FILE;
			}

		else
			{
			/* We matched some text prior to the EOB, first
			 * process it.
			 */
			return EOB_ACT_LAST_MATCH;
			}
		}

	/* Try to read more data. */

	/* First move last chars to start of buffer. */
	number_to_move = (int) (yyg->yy_c_buf_p - yyg->yytext_ptr) - 1;

	for ( i = 0; i < number_to_move; ++i )
		*(dest++) = *(source++);

	if ( YY_CURRENT_BUFFER_LVALUE->yy_buffer_status == YY_BUFFER_EOF_PENDING )
		/* don't do the read, it's not guaranteed to return an EOF,
		 * just force an EOF
		 */
		YY_CURRENT_BUFFER_LVALUE->yy_n_chars = yyg->yy_n_chars = 0;

	else
		{
			int num_to_read =
			YY_CURRENT_BUFFER_LVALUE->yy_buf_size - number_to_move - 1;

		while ( num_to_read <= 0 )
			{ /* Not enough room in the buffer - grow it. */

			/* just a shorter name for the current buffer */
			YY_BUFFER_STATE b = YY_CURRENT_BUFFER;

			int yy_c_buf_p_offset =
				(int) (yyg->yy_c_buf_p - b->yy_ch_buf);

			if ( b->yy_is_our_buffer )
				{
				int new_size = b->yy_buf_size * 2;

				if ( new_size <= 0 )
					b->yy_buf_size += b->yy_buf_size / 8;
				else
					b->yy_buf_size *= 2;

				b->yy_ch_buf = (char *)
					/* Include room in for 2 EOB chars. */
					_xkbcommon_realloc((void *) b->yy_ch_buf,b->yy_buf_size + 2 ,yyscanner );
				}
			else
				/* Can't grow it, we don't own it. */
				b->yy_ch_buf = 0;

			if ( ! b->yy_ch_buf )
				YY_FATAL_ERROR(
				"fatal error - scanner input buffer overflow" );

			yyg->yy_c_buf_p = &b->yy_ch_buf[yy_c_buf_p_offset];

			num_to_read = YY_CURRENT_BUFFER_LVALUE->yy_buf_size -
						number_to_move - 1;

			}

		if ( num_to_read > YY_READ_BUF_SIZE )
			num_to_read = YY_READ_BUF_SIZE;

		/* Read in more data. */
		YY_INPUT( (&YY_CURRENT_BUFFER_LVALUE->yy_ch_buf[number_to_move]),
			yyg->yy_n_chars, (size_t) num_to_read );

		YY_CURRENT_BUFFER_LVALUE->yy_n_chars = yyg->yy_n_chars;
		}

	if ( yyg->yy_n_chars == 0 )
		{
		if ( number_to_move == YY_MORE_ADJ )
			{
			ret_val = EOB_ACT_END_OF_FILE;
			_xkbcommon_restart(yyin  ,yyscanner);
			}

		else
			{
			ret_val = EOB_ACT_LAST_MATCH;
			YY_CURRENT_BUFFER_LVALUE->yy_buffer_status =
				YY_BUFFER_EOF_PENDING;
			}
		}

	else
		ret_val = EOB_ACT_CONTINUE_SCAN;

	if ((yy_size_t) (yyg->yy_n_chars + number_to_move) > YY_CURRENT_BUFFER_LVALUE->yy_buf_size) {
		/* Extend the array by 50%, plus the number we really need. */
		yy_size_t new_size = yyg->yy_n_chars + number_to_move + (yyg->yy_n_chars >> 1);
		YY_CURRENT_BUFFER_LVALUE->yy_ch_buf = (char *) _xkbcommon_realloc((void *) YY_CURRENT_BUFFER_LVALUE->yy_ch_buf,new_size ,yyscanner );
		if ( ! YY_CURRENT_BUFFER_LVALUE->yy_ch_buf )
			YY_FATAL_ERROR( "out of dynamic memory in yy_get_next_buffer()" );
	}

	yyg->yy_n_chars += number_to_move;
	YY_CURRENT_BUFFER_LVALUE->yy_ch_buf[yyg->yy_n_chars] = YY_END_OF_BUFFER_CHAR;
	YY_CURRENT_BUFFER_LVALUE->yy_ch_buf[yyg->yy_n_chars + 1] = YY_END_OF_BUFFER_CHAR;

	yyg->yytext_ptr = &YY_CURRENT_BUFFER_LVALUE->yy_ch_buf[0];

	return ret_val;
}

/* yy_get_previous_state - get the state just before the EOB char was reached */

    static yy_state_type yy_get_previous_state (yyscan_t yyscanner)
{
	register yy_state_type yy_current_state;
	register char *yy_cp;
    struct yyguts_t * yyg = (struct yyguts_t*)yyscanner;

	yy_current_state = yyg->yy_start;

	for ( yy_cp = yyg->yytext_ptr + YY_MORE_ADJ; yy_cp < yyg->yy_c_buf_p; ++yy_cp )
		{
		register YY_CHAR yy_c = (*yy_cp ? yy_ec[YY_SC_TO_UI(*yy_cp)] : 1);
		if ( yy_accept[yy_current_state] )
			{
			yyg->yy_last_accepting_state = yy_current_state;
			yyg->yy_last_accepting_cpos = yy_cp;
			}
		while ( yy_chk[yy_base[yy_current_state] + yy_c] != yy_current_state )
			{
			yy_current_state = (int) yy_def[yy_current_state];
			if ( yy_current_state >= 336 )
				yy_c = yy_meta[(unsigned int) yy_c];
			}
		yy_current_state = yy_nxt[yy_base[yy_current_state] + (unsigned int) yy_c];
		}

	return yy_current_state;
}

/* yy_try_NUL_trans - try to make a transition on the NUL character
 *
 * synopsis
 *	next_state = yy_try_NUL_trans( current_state );
 */
    static yy_state_type yy_try_NUL_trans  (yy_state_type yy_current_state , yyscan_t yyscanner)
{
	register int yy_is_jam;
    struct yyguts_t * yyg = (struct yyguts_t*)yyscanner; /* This var may be unused depending upon options. */
	register char *yy_cp = yyg->yy_c_buf_p;

	register YY_CHAR yy_c = 1;
	if ( yy_accept[yy_current_state] )
		{
		yyg->yy_last_accepting_state = yy_current_state;
		yyg->yy_last_accepting_cpos = yy_cp;
		}
	while ( yy_chk[yy_base[yy_current_state] + yy_c] != yy_current_state )
		{
		yy_current_state = (int) yy_def[yy_current_state];
		if ( yy_current_state >= 336 )
			yy_c = yy_meta[(unsigned int) yy_c];
		}
	yy_current_state = yy_nxt[yy_base[yy_current_state] + (unsigned int) yy_c];
	yy_is_jam = (yy_current_state == 335);

	return yy_is_jam ? 0 : yy_current_state;
}

#ifndef YY_NO_INPUT
#ifdef __cplusplus
    static int yyinput (yyscan_t yyscanner)
#else
    static int input  (yyscan_t yyscanner)
#endif

{
	int c;
    struct yyguts_t * yyg = (struct yyguts_t*)yyscanner;

	*yyg->yy_c_buf_p = yyg->yy_hold_char;

	if ( *yyg->yy_c_buf_p == YY_END_OF_BUFFER_CHAR )
		{
		/* yy_c_buf_p now points to the character we want to return.
		 * If this occurs *before* the EOB characters, then it's a
		 * valid NUL; if not, then we've hit the end of the buffer.
		 */
		if ( yyg->yy_c_buf_p < &YY_CURRENT_BUFFER_LVALUE->yy_ch_buf[yyg->yy_n_chars] )
			/* This was really a NUL. */
			*yyg->yy_c_buf_p = '\0';

		else
			{ /* need more input */
			int offset = yyg->yy_c_buf_p - yyg->yytext_ptr;
			++yyg->yy_c_buf_p;

			switch ( yy_get_next_buffer( yyscanner ) )
				{
				case EOB_ACT_LAST_MATCH:
					/* This happens because yy_g_n_b()
					 * sees that we've accumulated a
					 * token and flags that we need to
					 * try matching the token before
					 * proceeding.  But for input(),
					 * there's no matching to consider.
					 * So convert the EOB_ACT_LAST_MATCH
					 * to EOB_ACT_END_OF_FILE.
					 */

					/* Reset buffer status. */
					_xkbcommon_restart(yyin ,yyscanner);

					/*FALLTHROUGH*/

				case EOB_ACT_END_OF_FILE:
					{
					if ( _xkbcommon_wrap(yyscanner ) )
						return EOF;

					if ( ! yyg->yy_did_buffer_switch_on_eof )
						YY_NEW_FILE;
#ifdef __cplusplus
					return yyinput(yyscanner);
#else
					return input(yyscanner);
#endif
					}

				case EOB_ACT_CONTINUE_SCAN:
					yyg->yy_c_buf_p = yyg->yytext_ptr + offset;
					break;
				}
			}
		}

	c = *(unsigned char *) yyg->yy_c_buf_p;	/* cast for 8-bit char's */
	*yyg->yy_c_buf_p = '\0';	/* preserve yytext */
	yyg->yy_hold_char = *++yyg->yy_c_buf_p;

	if ( c == '\n' )
		   
    do{ yylineno++;
        yycolumn=0;
    }while(0)
;

	return c;
}
#endif	/* ifndef YY_NO_INPUT */

/** Immediately switch to a different input stream.
 * @param input_file A readable stream.
 * @param yyscanner The scanner object.
 * @note This function does not reset the start condition to @c INITIAL .
 */
    void _xkbcommon_restart  (FILE * input_file , yyscan_t yyscanner)
{
    struct yyguts_t * yyg = (struct yyguts_t*)yyscanner;

	if ( ! YY_CURRENT_BUFFER ){
        _xkbcommon_ensure_buffer_stack (yyscanner);
		YY_CURRENT_BUFFER_LVALUE =
            _xkbcommon__create_buffer(yyin,YY_BUF_SIZE ,yyscanner);
	}

	_xkbcommon__init_buffer(YY_CURRENT_BUFFER,input_file ,yyscanner);
	_xkbcommon__load_buffer_state(yyscanner );
}

/** Switch to a different input buffer.
 * @param new_buffer The new input buffer.
 * @param yyscanner The scanner object.
 */
    void _xkbcommon__switch_to_buffer  (YY_BUFFER_STATE  new_buffer , yyscan_t yyscanner)
{
    struct yyguts_t * yyg = (struct yyguts_t*)yyscanner;

	/* TODO. We should be able to replace this entire function body
	 * with
	 *		_xkbcommon_pop_buffer_state();
	 *		_xkbcommon_push_buffer_state(new_buffer);
     */
	_xkbcommon_ensure_buffer_stack (yyscanner);
	if ( YY_CURRENT_BUFFER == new_buffer )
		return;

	if ( YY_CURRENT_BUFFER )
		{
		/* Flush out information for old buffer. */
		*yyg->yy_c_buf_p = yyg->yy_hold_char;
		YY_CURRENT_BUFFER_LVALUE->yy_buf_pos = yyg->yy_c_buf_p;
		YY_CURRENT_BUFFER_LVALUE->yy_n_chars = yyg->yy_n_chars;
		}

	YY_CURRENT_BUFFER_LVALUE = new_buffer;
	_xkbcommon__load_buffer_state(yyscanner );

	/* We don't actually know whether we did this switch during
	 * EOF (_xkbcommon_wrap()) processing, but the only time this flag
	 * is looked at is after _xkbcommon_wrap() is called, so it's safe
	 * to go ahead and always set it.
	 */
	yyg->yy_did_buffer_switch_on_eof = 1;
}

static void _xkbcommon__load_buffer_state  (yyscan_t yyscanner)
{
    struct yyguts_t * yyg = (struct yyguts_t*)yyscanner;
	yyg->yy_n_chars = YY_CURRENT_BUFFER_LVALUE->yy_n_chars;
	yyg->yytext_ptr = yyg->yy_c_buf_p = YY_CURRENT_BUFFER_LVALUE->yy_buf_pos;
	yyin = YY_CURRENT_BUFFER_LVALUE->yy_input_file;
	yyg->yy_hold_char = *yyg->yy_c_buf_p;
}

/** Allocate and initialize an input buffer state.
 * @param file A readable stream.
 * @param size The character buffer size in bytes. When in doubt, use @c YY_BUF_SIZE.
 * @param yyscanner The scanner object.
 * @return the allocated buffer state.
 */
    YY_BUFFER_STATE _xkbcommon__create_buffer  (FILE * file, int  size , yyscan_t yyscanner)
{
	YY_BUFFER_STATE b;
    
	b = (YY_BUFFER_STATE) _xkbcommon_alloc(sizeof( struct yy_buffer_state ) ,yyscanner );
	if ( ! b )
		YY_FATAL_ERROR( "out of dynamic memory in _xkbcommon__create_buffer()" );

	b->yy_buf_size = size;

	/* yy_ch_buf has to be 2 characters longer than the size given because
	 * we need to put in 2 end-of-buffer characters.
	 */
	b->yy_ch_buf = (char *) _xkbcommon_alloc(b->yy_buf_size + 2 ,yyscanner );
	if ( ! b->yy_ch_buf )
		YY_FATAL_ERROR( "out of dynamic memory in _xkbcommon__create_buffer()" );

	b->yy_is_our_buffer = 1;

	_xkbcommon__init_buffer(b,file ,yyscanner);

	return b;
}

/** Destroy the buffer.
 * @param b a buffer created with _xkbcommon__create_buffer()
 * @param yyscanner The scanner object.
 */
    void _xkbcommon__delete_buffer (YY_BUFFER_STATE  b , yyscan_t yyscanner)
{
    struct yyguts_t * yyg = (struct yyguts_t*)yyscanner;

	if ( ! b )
		return;

	if ( b == YY_CURRENT_BUFFER ) /* Not sure if we should pop here. */
		YY_CURRENT_BUFFER_LVALUE = (YY_BUFFER_STATE) 0;

	if ( b->yy_is_our_buffer )
		_xkbcommon_free((void *) b->yy_ch_buf ,yyscanner );

	_xkbcommon_free((void *) b ,yyscanner );
}

/* Initializes or reinitializes a buffer.
 * This function is sometimes called more than once on the same buffer,
 * such as during a _xkbcommon_restart() or at EOF.
 */
    static void _xkbcommon__init_buffer  (YY_BUFFER_STATE  b, FILE * file , yyscan_t yyscanner)

{
	int oerrno = errno;
    struct yyguts_t * yyg = (struct yyguts_t*)yyscanner;

	_xkbcommon__flush_buffer(b ,yyscanner);

	b->yy_input_file = file;
	b->yy_fill_buffer = 1;

    /* If b is the current buffer, then _xkbcommon__init_buffer was _probably_
     * called from _xkbcommon_restart() or through yy_get_next_buffer.
     * In that case, we don't want to reset the lineno or column.
     */
    if (b != YY_CURRENT_BUFFER){
        b->yy_bs_lineno = 1;
        b->yy_bs_column = 0;
    }

        b->yy_is_interactive = 0;
    
	errno = oerrno;
}

/** Discard all buffered characters. On the next scan, YY_INPUT will be called.
 * @param b the buffer state to be flushed, usually @c YY_CURRENT_BUFFER.
 * @param yyscanner The scanner object.
 */
    void _xkbcommon__flush_buffer (YY_BUFFER_STATE  b , yyscan_t yyscanner)
{
    struct yyguts_t * yyg = (struct yyguts_t*)yyscanner;
	if ( ! b )
		return;

	b->yy_n_chars = 0;

	/* We always need two end-of-buffer characters.  The first causes
	 * a transition to the end-of-buffer state.  The second causes
	 * a jam in that state.
	 */
	b->yy_ch_buf[0] = YY_END_OF_BUFFER_CHAR;
	b->yy_ch_buf[1] = YY_END_OF_BUFFER_CHAR;

	b->yy_buf_pos = &b->yy_ch_buf[0];

	b->yy_at_bol = 1;
	b->yy_buffer_status = YY_BUFFER_NEW;

	if ( b == YY_CURRENT_BUFFER )
		_xkbcommon__load_buffer_state(yyscanner );
}

/** Pushes the new state onto the stack. The new state becomes
 *  the current state. This function will allocate the stack
 *  if necessary.
 *  @param new_buffer The new state.
 *  @param yyscanner The scanner object.
 */
void _xkbcommon_push_buffer_state (YY_BUFFER_STATE new_buffer , yyscan_t yyscanner)
{
    struct yyguts_t * yyg = (struct yyguts_t*)yyscanner;
	if (new_buffer == NULL)
		return;

	_xkbcommon_ensure_buffer_stack(yyscanner);

	/* This block is copied from _xkbcommon__switch_to_buffer. */
	if ( YY_CURRENT_BUFFER )
		{
		/* Flush out information for old buffer. */
		*yyg->yy_c_buf_p = yyg->yy_hold_char;
		YY_CURRENT_BUFFER_LVALUE->yy_buf_pos = yyg->yy_c_buf_p;
		YY_CURRENT_BUFFER_LVALUE->yy_n_chars = yyg->yy_n_chars;
		}

	/* Only push if top exists. Otherwise, replace top. */
	if (YY_CURRENT_BUFFER)
		yyg->yy_buffer_stack_top++;
	YY_CURRENT_BUFFER_LVALUE = new_buffer;

	/* copied from _xkbcommon__switch_to_buffer. */
	_xkbcommon__load_buffer_state(yyscanner );
	yyg->yy_did_buffer_switch_on_eof = 1;
}

/** Removes and deletes the top of the stack, if present.
 *  The next element becomes the new top.
 *  @param yyscanner The scanner object.
 */
void _xkbcommon_pop_buffer_state (yyscan_t yyscanner)
{
    struct yyguts_t * yyg = (struct yyguts_t*)yyscanner;
	if (!YY_CURRENT_BUFFER)
		return;

	_xkbcommon__delete_buffer(YY_CURRENT_BUFFER ,yyscanner);
	YY_CURRENT_BUFFER_LVALUE = NULL;
	if (yyg->yy_buffer_stack_top > 0)
		--yyg->yy_buffer_stack_top;

	if (YY_CURRENT_BUFFER) {
		_xkbcommon__load_buffer_state(yyscanner );
		yyg->yy_did_buffer_switch_on_eof = 1;
	}
}

/* Allocates the stack if it does not exist.
 *  Guarantees space for at least one push.
 */
static void _xkbcommon_ensure_buffer_stack (yyscan_t yyscanner)
{
	int num_to_alloc;
    struct yyguts_t * yyg = (struct yyguts_t*)yyscanner;

	if (!yyg->yy_buffer_stack) {

		/* First allocation is just for 2 elements, since we don't know if this
		 * scanner will even need a stack. We use 2 instead of 1 to avoid an
		 * immediate realloc on the next call.
         */
		num_to_alloc = 1;
		yyg->yy_buffer_stack = (struct yy_buffer_state**)_xkbcommon_alloc
								(num_to_alloc * sizeof(struct yy_buffer_state*)
								, yyscanner);
		if ( ! yyg->yy_buffer_stack )
			YY_FATAL_ERROR( "out of dynamic memory in _xkbcommon_ensure_buffer_stack()" );
								  
		memset(yyg->yy_buffer_stack, 0, num_to_alloc * sizeof(struct yy_buffer_state*));
				
		yyg->yy_buffer_stack_max = num_to_alloc;
		yyg->yy_buffer_stack_top = 0;
		return;
	}

	if (yyg->yy_buffer_stack_top >= (yyg->yy_buffer_stack_max) - 1){

		/* Increase the buffer to prepare for a possible push. */
		int grow_size = 8 /* arbitrary grow size */;

		num_to_alloc = yyg->yy_buffer_stack_max + grow_size;
		yyg->yy_buffer_stack = (struct yy_buffer_state**)_xkbcommon_realloc
								(yyg->yy_buffer_stack,
								num_to_alloc * sizeof(struct yy_buffer_state*)
								, yyscanner);
		if ( ! yyg->yy_buffer_stack )
			YY_FATAL_ERROR( "out of dynamic memory in _xkbcommon_ensure_buffer_stack()" );

		/* zero only the new slots.*/
		memset(yyg->yy_buffer_stack + yyg->yy_buffer_stack_max, 0, grow_size * sizeof(struct yy_buffer_state*));
		yyg->yy_buffer_stack_max = num_to_alloc;
	}
}

/** Setup the input buffer state to scan directly from a user-specified character buffer.
 * @param base the character buffer
 * @param size the size in bytes of the character buffer
 * @param yyscanner The scanner object.
 * @return the newly allocated buffer state object. 
 */
YY_BUFFER_STATE _xkbcommon__scan_buffer  (char * base, yy_size_t  size , yyscan_t yyscanner)
{
	YY_BUFFER_STATE b;
    
	if ( size < 2 ||
	     base[size-2] != YY_END_OF_BUFFER_CHAR ||
	     base[size-1] != YY_END_OF_BUFFER_CHAR )
		/* They forgot to leave room for the EOB's. */
		return 0;

	b = (YY_BUFFER_STATE) _xkbcommon_alloc(sizeof( struct yy_buffer_state ) ,yyscanner );
	if ( ! b )
		YY_FATAL_ERROR( "out of dynamic memory in _xkbcommon__scan_buffer()" );

	b->yy_buf_size = size - 2;	/* "- 2" to take care of EOB's */
	b->yy_buf_pos = b->yy_ch_buf = base;
	b->yy_is_our_buffer = 0;
	b->yy_input_file = 0;
	b->yy_n_chars = b->yy_buf_size;
	b->yy_is_interactive = 0;
	b->yy_at_bol = 1;
	b->yy_fill_buffer = 0;
	b->yy_buffer_status = YY_BUFFER_NEW;

	_xkbcommon__switch_to_buffer(b ,yyscanner );

	return b;
}

/** Setup the input buffer state to scan a string. The next call to _xkbcommon_lex() will
 * scan from a @e copy of @a str.
 * @param yystr a NUL-terminated string to scan
 * @param yyscanner The scanner object.
 * @return the newly allocated buffer state object.
 * @note If you want to scan bytes that may contain NUL values, then use
 *       _xkbcommon__scan_bytes() instead.
 */
YY_BUFFER_STATE _xkbcommon__scan_string (yyconst char * yystr , yyscan_t yyscanner)
{
    
	return _xkbcommon__scan_bytes(yystr,strlen(yystr) ,yyscanner);
}

/** Setup the input buffer state to scan the given bytes. The next call to _xkbcommon_lex() will
 * scan from a @e copy of @a bytes.
 * @param yybytes the byte buffer to scan
 * @param _yybytes_len the number of bytes in the buffer pointed to by @a bytes.
 * @param yyscanner The scanner object.
 * @return the newly allocated buffer state object.
 */
YY_BUFFER_STATE _xkbcommon__scan_bytes  (yyconst char * yybytes, int  _yybytes_len , yyscan_t yyscanner)
{
	YY_BUFFER_STATE b;
	char *buf;
	yy_size_t n;
	int i;
    
	/* Get memory for full buffer, including space for trailing EOB's. */
	n = _yybytes_len + 2;
	buf = (char *) _xkbcommon_alloc(n ,yyscanner );
	if ( ! buf )
		YY_FATAL_ERROR( "out of dynamic memory in _xkbcommon__scan_bytes()" );

	for ( i = 0; i < _yybytes_len; ++i )
		buf[i] = yybytes[i];

	buf[_yybytes_len] = buf[_yybytes_len+1] = YY_END_OF_BUFFER_CHAR;

	b = _xkbcommon__scan_buffer(buf,n ,yyscanner);
	if ( ! b )
		YY_FATAL_ERROR( "bad buffer in _xkbcommon__scan_bytes()" );

	/* It's okay to grow etc. this buffer, and we should throw it
	 * away when we're done.
	 */
	b->yy_is_our_buffer = 1;

	return b;
}

#ifndef YY_EXIT_FAILURE
#define YY_EXIT_FAILURE 2
#endif

static void yy_fatal_error (yyconst char* msg , yyscan_t yyscanner)
{
    	(void) fprintf( stderr, "%s\n", msg );
	exit( YY_EXIT_FAILURE );
}

/* Redefine yyless() so it works in section 3 code. */

#undef yyless
#define yyless(n) \
	do \
		{ \
		/* Undo effects of setting up yytext. */ \
        int yyless_macro_arg = (n); \
        YY_LESS_LINENO(yyless_macro_arg);\
		yytext[yyleng] = yyg->yy_hold_char; \
		yyg->yy_c_buf_p = yytext + yyless_macro_arg; \
		yyg->yy_hold_char = *yyg->yy_c_buf_p; \
		*yyg->yy_c_buf_p = '\0'; \
		yyleng = yyless_macro_arg; \
		} \
	while ( 0 )

/* Accessor  methods (get/set functions) to struct members. */

/** Get the user-defined data for this scanner.
 * @param yyscanner The scanner object.
 */
YY_EXTRA_TYPE _xkbcommon_get_extra  (yyscan_t yyscanner)
{
    struct yyguts_t * yyg = (struct yyguts_t*)yyscanner;
    return yyextra;
}

/** Get the current line number.
 * @param yyscanner The scanner object.
 */
int _xkbcommon_get_lineno  (yyscan_t yyscanner)
{
    struct yyguts_t * yyg = (struct yyguts_t*)yyscanner;
    
        if (! YY_CURRENT_BUFFER)
            return 0;
    
    return yylineno;
}

/** Get the current column number.
 * @param yyscanner The scanner object.
 */
int _xkbcommon_get_column  (yyscan_t yyscanner)
{
    struct yyguts_t * yyg = (struct yyguts_t*)yyscanner;
    
        if (! YY_CURRENT_BUFFER)
            return 0;
    
    return yycolumn;
}

/** Get the input stream.
 * @param yyscanner The scanner object.
 */
FILE *_xkbcommon_get_in  (yyscan_t yyscanner)
{
    struct yyguts_t * yyg = (struct yyguts_t*)yyscanner;
    return yyin;
}

/** Get the output stream.
 * @param yyscanner The scanner object.
 */
FILE *_xkbcommon_get_out  (yyscan_t yyscanner)
{
    struct yyguts_t * yyg = (struct yyguts_t*)yyscanner;
    return yyout;
}

/** Get the length of the current token.
 * @param yyscanner The scanner object.
 */
int _xkbcommon_get_leng  (yyscan_t yyscanner)
{
    struct yyguts_t * yyg = (struct yyguts_t*)yyscanner;
    return yyleng;
}

/** Get the current token.
 * @param yyscanner The scanner object.
 */

char *_xkbcommon_get_text  (yyscan_t yyscanner)
{
    struct yyguts_t * yyg = (struct yyguts_t*)yyscanner;
    return yytext;
}

/** Set the user-defined data. This data is never touched by the scanner.
 * @param user_defined The data to be associated with this scanner.
 * @param yyscanner The scanner object.
 */
void _xkbcommon_set_extra (YY_EXTRA_TYPE  user_defined , yyscan_t yyscanner)
{
    struct yyguts_t * yyg = (struct yyguts_t*)yyscanner;
    yyextra = user_defined ;
}

/** Set the current line number.
 * @param line_number
 * @param yyscanner The scanner object.
 */
void _xkbcommon_set_lineno (int  line_number , yyscan_t yyscanner)
{
    struct yyguts_t * yyg = (struct yyguts_t*)yyscanner;

        /* lineno is only valid if an input buffer exists. */
        if (! YY_CURRENT_BUFFER )
           yy_fatal_error( "_xkbcommon_set_lineno called with no buffer" , yyscanner); 
    
    yylineno = line_number;
}

/** Set the current column.
 * @param line_number
 * @param yyscanner The scanner object.
 */
void _xkbcommon_set_column (int  column_no , yyscan_t yyscanner)
{
    struct yyguts_t * yyg = (struct yyguts_t*)yyscanner;

        /* column is only valid if an input buffer exists. */
        if (! YY_CURRENT_BUFFER )
           yy_fatal_error( "_xkbcommon_set_column called with no buffer" , yyscanner); 
    
    yycolumn = column_no;
}

/** Set the input stream. This does not discard the current
 * input buffer.
 * @param in_str A readable stream.
 * @param yyscanner The scanner object.
 * @see _xkbcommon__switch_to_buffer
 */
void _xkbcommon_set_in (FILE *  in_str , yyscan_t yyscanner)
{
    struct yyguts_t * yyg = (struct yyguts_t*)yyscanner;
    yyin = in_str ;
}

void _xkbcommon_set_out (FILE *  out_str , yyscan_t yyscanner)
{
    struct yyguts_t * yyg = (struct yyguts_t*)yyscanner;
    yyout = out_str ;
}

int _xkbcommon_get_debug  (yyscan_t yyscanner)
{
    struct yyguts_t * yyg = (struct yyguts_t*)yyscanner;
    return yy_flex_debug;
}

void _xkbcommon_set_debug (int  bdebug , yyscan_t yyscanner)
{
    struct yyguts_t * yyg = (struct yyguts_t*)yyscanner;
    yy_flex_debug = bdebug ;
}

/* Accessor methods for yylval and yylloc */

YYSTYPE * _xkbcommon_get_lval  (yyscan_t yyscanner)
{
    struct yyguts_t * yyg = (struct yyguts_t*)yyscanner;
    return yylval;
}

void _xkbcommon_set_lval (YYSTYPE *  yylval_param , yyscan_t yyscanner)
{
    struct yyguts_t * yyg = (struct yyguts_t*)yyscanner;
    yylval = yylval_param;
}

YYLTYPE *_xkbcommon_get_lloc  (yyscan_t yyscanner)
{
    struct yyguts_t * yyg = (struct yyguts_t*)yyscanner;
    return yylloc;
}
    
void _xkbcommon_set_lloc (YYLTYPE *  yylloc_param , yyscan_t yyscanner)
{
    struct yyguts_t * yyg = (struct yyguts_t*)yyscanner;
    yylloc = yylloc_param;
}
    
/* User-visible API */

/* _xkbcommon_lex_init is special because it creates the scanner itself, so it is
 * the ONLY reentrant function that doesn't take the scanner as the last argument.
 * That's why we explicitly handle the declaration, instead of using our macros.
 */

int _xkbcommon_lex_init(yyscan_t* ptr_yy_globals)

{
    if (ptr_yy_globals == NULL){
        errno = EINVAL;
        return 1;
    }

    *ptr_yy_globals = (yyscan_t) _xkbcommon_alloc ( sizeof( struct yyguts_t ), NULL );

    if (*ptr_yy_globals == NULL){
        errno = ENOMEM;
        return 1;
    }

    /* By setting to 0xAA, we expose bugs in yy_init_globals. Leave at 0x00 for releases. */
    memset(*ptr_yy_globals,0x00,sizeof(struct yyguts_t));

    return yy_init_globals ( *ptr_yy_globals );
}

/* _xkbcommon_lex_init_extra has the same functionality as _xkbcommon_lex_init, but follows the
 * convention of taking the scanner as the last argument. Note however, that
 * this is a *pointer* to a scanner, as it will be allocated by this call (and
 * is the reason, too, why this function also must handle its own declaration).
 * The user defined value in the first argument will be available to _xkbcommon_alloc in
 * the yyextra field.
 */

int _xkbcommon_lex_init_extra(YY_EXTRA_TYPE yy_user_defined,yyscan_t* ptr_yy_globals )

{
    struct yyguts_t dummy_yyguts;

    _xkbcommon_set_extra (yy_user_defined, &dummy_yyguts);

    if (ptr_yy_globals == NULL){
        errno = EINVAL;
        return 1;
    }
	
    *ptr_yy_globals = (yyscan_t) _xkbcommon_alloc ( sizeof( struct yyguts_t ), &dummy_yyguts );
	
    if (*ptr_yy_globals == NULL){
        errno = ENOMEM;
        return 1;
    }
    
    /* By setting to 0xAA, we expose bugs in
    yy_init_globals. Leave at 0x00 for releases. */
    memset(*ptr_yy_globals,0x00,sizeof(struct yyguts_t));
    
    _xkbcommon_set_extra (yy_user_defined, *ptr_yy_globals);
    
    return yy_init_globals ( *ptr_yy_globals );
}

static int yy_init_globals (yyscan_t yyscanner)
{
    struct yyguts_t * yyg = (struct yyguts_t*)yyscanner;
    /* Initialization is the same as for the non-reentrant scanner.
     * This function is called from _xkbcommon_lex_destroy(), so don't allocate here.
     */

    yyg->yy_buffer_stack = 0;
    yyg->yy_buffer_stack_top = 0;
    yyg->yy_buffer_stack_max = 0;
    yyg->yy_c_buf_p = (char *) 0;
    yyg->yy_init = 0;
    yyg->yy_start = 0;

    yyg->yy_start_stack_ptr = 0;
    yyg->yy_start_stack_depth = 0;
    yyg->yy_start_stack =  NULL;

/* Defined in main.c */
#ifdef YY_STDINIT
    yyin = stdin;
    yyout = stdout;
#else
    yyin = (FILE *) 0;
    yyout = (FILE *) 0;
#endif

    /* For future reference: Set errno on error, since we are called by
     * _xkbcommon_lex_init()
     */
    return 0;
}

/* _xkbcommon_lex_destroy is for both reentrant and non-reentrant scanners. */
int _xkbcommon_lex_destroy  (yyscan_t yyscanner)
{
    struct yyguts_t * yyg = (struct yyguts_t*)yyscanner;

    /* Pop the buffer stack, destroying each element. */
	while(YY_CURRENT_BUFFER){
		_xkbcommon__delete_buffer(YY_CURRENT_BUFFER ,yyscanner );
		YY_CURRENT_BUFFER_LVALUE = NULL;
		_xkbcommon_pop_buffer_state(yyscanner);
	}

	/* Destroy the stack itself. */
	_xkbcommon_free(yyg->yy_buffer_stack ,yyscanner);
	yyg->yy_buffer_stack = NULL;

    /* Destroy the start condition stack. */
        _xkbcommon_free(yyg->yy_start_stack ,yyscanner );
        yyg->yy_start_stack = NULL;

    /* Reset the globals. This is important in a non-reentrant scanner so the next time
     * _xkbcommon_lex() is called, initialization will occur. */
    yy_init_globals( yyscanner);

    /* Destroy the main struct (reentrant only). */
    _xkbcommon_free ( yyscanner , yyscanner );
    yyscanner = NULL;
    return 0;
}

/*
 * Internal utility routines.
 */

#ifndef yytext_ptr
static void yy_flex_strncpy (char* s1, yyconst char * s2, int n , yyscan_t yyscanner)
{
	register int i;
	for ( i = 0; i < n; ++i )
		s1[i] = s2[i];
}
#endif

#ifdef YY_NEED_STRLEN
static int yy_flex_strlen (yyconst char * s , yyscan_t yyscanner)
{
	register int n;
	for ( n = 0; s[n]; ++n )
		;

	return n;
}
#endif

void *_xkbcommon_alloc (yy_size_t  size , yyscan_t yyscanner)
{
	return (void *) malloc( size );
}

void *_xkbcommon_realloc  (void * ptr, yy_size_t  size , yyscan_t yyscanner)
{
	/* The cast to (char *) in the following accommodates both
	 * implementations that use char* generic pointers, and those
	 * that use void* generic pointers.  It works with the latter
	 * because both ANSI C and C++ allow castless assignment from
	 * any pointer type to void*, and deal with argument conversions
	 * as though doing an assignment.
	 */
	return (void *) realloc( (char *) ptr, size );
}

void _xkbcommon_free (void * ptr , yyscan_t yyscanner)
{
	free( (char *) ptr );	/* see _xkbcommon_realloc() for (char *) cast */
}

#define YYTABLES_NAME "yytables"

#line 207 "scanner.l"



#pragma GCC diagnostic pop

static void
scanner_error_extra(struct YYLTYPE *loc, struct scanner_extra *extra,
                    const char *msg)
{
    log_err(extra->ctx, "%s: line %d of %s\n", msg,
            loc->first_line,
            extra->file_name ? extra->file_name : "(unknown)");
}

void
scanner_error(struct YYLTYPE *loc, void *scanner, const char *msg)
{
    struct scanner_extra *extra = _xkbcommon_get_extra(scanner);
    scanner_error_extra(loc, extra, msg);
}

static bool
init_scanner(yyscan_t *scanner, struct scanner_extra *extra,
             struct xkb_context *ctx, const char *file_name)
{
    memset(extra, 0, sizeof(*extra));

    if (_xkbcommon_lex_init_extra(extra,scanner) != 0)
        return false;

    extra->ctx = ctx;
    extra->file_name = file_name;

    return true;
}

static void
clear_scanner(yyscan_t scanner)
{
    _xkbcommon_lex_destroy(scanner);
}

XkbFile *
XkbParseString(struct xkb_context *ctx, const char *string,
               const char *file_name)
{
    yyscan_t scanner;
    struct scanner_extra extra;
    YY_BUFFER_STATE state;
    XkbFile *xkb_file;

    if (!init_scanner(&scanner, &extra, ctx, file_name))
        return NULL;

    state = _xkbcommon__scan_string(string,scanner);

    xkb_file = parse(ctx, scanner, NULL);

    _xkbcommon__delete_buffer(state,scanner);
    clear_scanner(scanner);

    return xkb_file;
}

/*
 * _xkbcommon__scan_buffer() requires the last two bytes of \buf to be 0. These two bytes
 * are not scanned. Other zero bytes in the buffer are scanned normally, though.
 * Due to these terminating zeroes, \length must be greater than 2.
 * Furthermore, the buffer must be writable and you cannot make any assumptions
 * about it after the scanner finished.
 * All this must be guaranteed by the caller of this function!
 */
XkbFile *
XkbParseBuffer(struct xkb_context *ctx, char *buf, size_t length,
               const char *file_name)
{
    yyscan_t scanner;
    struct scanner_extra extra;
    YY_BUFFER_STATE state;
    XkbFile *xkb_file;

    if (!init_scanner(&scanner, &extra, ctx, file_name))
        return NULL;

    xkb_file = NULL;
    state = _xkbcommon__scan_buffer(buf,length,scanner);
    if (state) {
        xkb_file = parse(ctx, scanner, NULL);
        _xkbcommon__delete_buffer(state,scanner);
    }

    clear_scanner(scanner);

    return xkb_file;
}

XkbFile *
XkbParseFile(struct xkb_context *ctx, FILE *file,
             const char *file_name, const char *map)
{
    yyscan_t scanner;
    struct scanner_extra extra;
    YY_BUFFER_STATE state;
    XkbFile *xkb_file;

    if (!init_scanner(&scanner, &extra, ctx, file_name))
        return NULL;

    state = _xkbcommon__create_buffer(file,YY_BUF_SIZE,scanner);
    _xkbcommon__switch_to_buffer(state,scanner);

    xkb_file = parse(ctx, scanner, map);

    _xkbcommon__delete_buffer(state,scanner);
    clear_scanner(scanner);

    return xkb_file;
}

